# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.thread_metadata import ThreadMetadata

class TestThreadMetadata(unittest.TestCase):
    """ThreadMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThreadMetadata:
        """Test ThreadMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThreadMetadata`
        """
        model = ThreadMetadata()
        if include_optional:
            return ThreadMetadata(
                status = 'draft',
                project_brief_drafts = [
                    keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], )
                    ],
                project_brief_document_versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ]
            )
        else:
            return ThreadMetadata(
        )
        """

    def testThreadMetadata(self):
        """Test ThreadMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
