# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_thematic_analysis import ArtifactDataThematicAnalysis

class TestArtifactDataThematicAnalysis(unittest.TestCase):
    """ArtifactDataThematicAnalysis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataThematicAnalysis:
        """Test ArtifactDataThematicAnalysis
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataThematicAnalysis`
        """
        model = ArtifactDataThematicAnalysis()
        if include_optional:
            return ArtifactDataThematicAnalysis(
                kind = 'thematic_analysis',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], )
            )
        else:
            return ArtifactDataThematicAnalysis(
                kind = 'thematic_analysis',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
        )
        """

    def testArtifactDataThematicAnalysis(self):
        """Test ArtifactDataThematicAnalysis"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
