# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.call_metadata import CallMetadata

class TestCallMetadata(unittest.TestCase):
    """CallMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CallMetadata:
        """Test CallMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CallMetadata`
        """
        model = CallMetadata()
        if include_optional:
            return CallMetadata(
                recording_url = '',
                transcript = '',
                transcript_quality = 'HIGH',
                transcript_markdown = '',
                transcript_insight = '',
                analysis = keplar_api.models.call_analysis.CallAnalysis(
                    summary = '', 
                    success_evaluation = '', ),
                gcs_url = '',
                gcs_path = '',
                gcs_uploaded_at = '',
                gcs_last_synced_at = '',
                video_recording_url = '',
                video_gcs_url = '',
                video_gcs_path = '',
                video_uploaded_at = '',
                video_mime_type = '',
                video_duration_seconds = 1.337,
                video_size_bytes = 1.337,
                video_recording_status = 'recording',
                video_recording_error = ''
            )
        else:
            return CallMetadata(
        )
        """

    def testCallMetadata(self):
        """Test CallMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
