# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_orgs200_response import GetOrgs200Response

class TestGetOrgs200Response(unittest.TestCase):
    """GetOrgs200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetOrgs200Response:
        """Test GetOrgs200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetOrgs200Response`
        """
        model = GetOrgs200Response()
        if include_optional:
            return GetOrgs200Response(
                items = [
                    keplar_api.models.get_orgs_200_response_items_inner.getOrgs_200_response_items_inner(
                        id = '', 
                        name = '', 
                        domain = '', 
                        is2_fa_enabled = True, 
                        default_workspace_id = '', 
                        default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                            id = '', 
                            name = '', ), 
                        stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                            total_projects = 1.337, 
                            total_responses_completed = 1.337, 
                            total_responses = 1.337, 
                            total_members = 1.337, 
                            last_activity_at = '', ), 
                        created_at = '', 
                        updated_at = '', )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetOrgs200Response(
                items = [
                    keplar_api.models.get_orgs_200_response_items_inner.getOrgs_200_response_items_inner(
                        id = '', 
                        name = '', 
                        domain = '', 
                        is2_fa_enabled = True, 
                        default_workspace_id = '', 
                        default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                            id = '', 
                            name = '', ), 
                        stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                            total_projects = 1.337, 
                            total_responses_completed = 1.337, 
                            total_responses = 1.337, 
                            total_members = 1.337, 
                            last_activity_at = '', ), 
                        created_at = '', 
                        updated_at = '', )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetOrgs200Response(self):
        """Test GetOrgs200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
