# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.code_invite_config import CodeInviteConfig

class TestCodeInviteConfig(unittest.TestCase):
    """CodeInviteConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CodeInviteConfig:
        """Test CodeInviteConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CodeInviteConfig`
        """
        model = CodeInviteConfig()
        if include_optional:
            return CodeInviteConfig(
                kind = 'BYO_PANEL',
                collect_email = True,
                require_email = True,
                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                    respondent_attributes = [
                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                            qualifications = [
                                keplar_api.models.panel_qualification.PanelQualification(
                                    allowed_option_ids = [
                                        null
                                        ], 
                                    question_id = 1.337, )
                                ], 
                            quota = 1.337, 
                            quota_name = '', )
                        ], 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    compensation = 1.337, ),
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, ),
                is_test = True,
                show_call_metadata = True,
                allowed_origins = [
                    ''
                    ],
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], )
            )
        else:
            return CodeInviteConfig(
                kind = 'BYO_PANEL',
                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                    respondent_attributes = [
                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                            qualifications = [
                                keplar_api.models.panel_qualification.PanelQualification(
                                    allowed_option_ids = [
                                        null
                                        ], 
                                    question_id = 1.337, )
                                ], 
                            quota = 1.337, 
                            quota_name = '', )
                        ], 
                    country_code = '', 
                    language_code = '', 
                    length_of_interview = 1.337, 
                    incidence_rate = 1.337, 
                    compensation = 1.337, ),
                title = '',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
        )
        """

    def testCodeInviteConfig(self):
        """Test CodeInviteConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
