# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_threads_thread_id_project_brief_document_versions_version_put200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response

class TestApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(unittest.TestCase):
    """ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response:
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response`
        """
        model = ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response()
        if include_optional:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(
                version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                    doc = keplar_api.models.brief_document.BriefDocument(
                        type = 'doc', 
                        content = [
                            keplar_api.models.content_node.ContentNode()
                            ], ), 
                    version = 1.337, 
                    created_at = '', 
                    updated_at = '', )
            )
        else:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(
                version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                    doc = keplar_api.models.brief_document.BriefDocument(
                        type = 'doc', 
                        content = [
                            keplar_api.models.content_node.ContentNode()
                            ], ), 
                    version = 1.337, 
                    created_at = '', 
                    updated_at = '', ),
        )
        """

    def testApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response(self):
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
