# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_notebook_artifact_request import CreateNotebookArtifactRequest

class TestCreateNotebookArtifactRequest(unittest.TestCase):
    """CreateNotebookArtifactRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNotebookArtifactRequest:
        """Test CreateNotebookArtifactRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNotebookArtifactRequest`
        """
        model = CreateNotebookArtifactRequest()
        if include_optional:
            return CreateNotebookArtifactRequest(
                kind = 'thematic_analysis',
                metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                    status = 'draft', 
                    status_message = '', 
                    progress = 1.337, 
                    description = '', ),
                data = keplar_api.models.artifact_data_not_null.ArtifactDataNotNull()
            )
        else:
            return CreateNotebookArtifactRequest(
        )
        """

    def testCreateNotebookArtifactRequest(self):
        """Test CreateNotebookArtifactRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
