# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.vapi_voice_id import VapiVoiceId

class TestVapiVoiceId(unittest.TestCase):
    """VapiVoiceId unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVapiVoiceId(self):
        """Test VapiVoiceId"""
        # inst = VapiVoiceId()

if __name__ == '__main__':
    unittest.main()
