# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_project_preview_invite_request import CreateProjectPreviewInviteRequest

class TestCreateProjectPreviewInviteRequest(unittest.TestCase):
    """CreateProjectPreviewInviteRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateProjectPreviewInviteRequest:
        """Test CreateProjectPreviewInviteRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateProjectPreviewInviteRequest`
        """
        model = CreateProjectPreviewInviteRequest()
        if include_optional:
            return CreateProjectPreviewInviteRequest(
                title = '',
                description = '',
                target_email = ''
            )
        else:
            return CreateProjectPreviewInviteRequest(
        )
        """

    def testCreateProjectPreviewInviteRequest(self):
        """Test CreateProjectPreviewInviteRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
