# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_config_byo_panel import InviteConfigByoPanel

class TestInviteConfigByoPanel(unittest.TestCase):
    """InviteConfigByoPanel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteConfigByoPanel:
        """Test InviteConfigByoPanel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteConfigByoPanel`
        """
        model = InviteConfigByoPanel()
        if include_optional:
            return InviteConfigByoPanel(
                kind = 'BYO_PANEL',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, )
            )
        else:
            return InviteConfigByoPanel(
                kind = 'BYO_PANEL',
                byo_panel_config = keplar_api.models.byo_panel_repdata_config.ByoPanelRepdataConfig(
                    kind = 'REPDATA', 
                    selected_qualifications = [
                        keplar_api.models.repdata_qualification.RepdataQualification(
                            question_id = 1.337, 
                            allowed_option_ids = [
                                null
                                ], )
                        ], ),
                title = '',
        )
        """

    def testInviteConfigByoPanel(self):
        """Test InviteConfigByoPanel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
