# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.video_recording_settings import VideoRecordingSettings
from typing import Optional, Set
from typing_extensions import Self

class CodeInviteConfigContacts(BaseModel):
    """
    CodeInviteConfigContacts
    """ # noqa: E501
    kind: StrictStr
    is_test: Optional[StrictBool] = Field(default=None, alias="isTest")
    show_call_metadata: Optional[StrictBool] = Field(default=None, alias="showCallMetadata")
    title: StrictStr
    description: Optional[StrictStr] = None
    max_responses: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxResponses")
    max_responses_per_participant: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxResponsesPerParticipant")
    video_recording: Optional[VideoRecordingSettings] = Field(default=None, alias="videoRecording")
    __properties: ClassVar[List[str]] = ["kind", "isTest", "showCallMetadata", "title", "description", "maxResponses", "maxResponsesPerParticipant", "videoRecording"]

    @field_validator('kind')
    def kind_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['CONTACTS']):
            raise ValueError("must be one of enum values ('CONTACTS')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CodeInviteConfigContacts from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of video_recording
        if self.video_recording:
            _dict['videoRecording'] = self.video_recording.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CodeInviteConfigContacts from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "kind": obj.get("kind"),
            "isTest": obj.get("isTest"),
            "showCallMetadata": obj.get("showCallMetadata"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "maxResponses": obj.get("maxResponses"),
            "maxResponsesPerParticipant": obj.get("maxResponsesPerParticipant"),
            "videoRecording": VideoRecordingSettings.from_dict(obj["videoRecording"]) if obj.get("videoRecording") is not None else None
        })
        return _obj


