# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_not_null import ArtifactDataNotNull

class TestArtifactDataNotNull(unittest.TestCase):
    """ArtifactDataNotNull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataNotNull:
        """Test ArtifactDataNotNull
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataNotNull`
        """
        model = ArtifactDataNotNull()
        if include_optional:
            return ArtifactDataNotNull(
                kind = 'presentation',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
                report = '',
                references = {
                    'key' : ''
                    },
                call_ids = [
                    ''
                    ],
                projects = [
                    keplar_api.models.artifact_data_report_projects_inner.ArtifactDataReport_projects_inner(
                        id = '', 
                        name = '', 
                        participants = 1.337, )
                    ],
                thread_id = '',
                query = '',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
                gamma_generation_id = '',
                gamma_url = '',
                export_url = ''
            )
        else:
            return ArtifactDataNotNull(
                kind = 'presentation',
                data = keplar_api.models.artifact_data_thematic_analysis_data.ArtifactDataThematicAnalysis_data(
                    query = '', 
                    summary = '', 
                    themes = [
                        keplar_api.models.artifact_data_thematic_analysis_data_themes_inner.ArtifactDataThematicAnalysis_data_themes_inner(
                            label = '', 
                            description = '', )
                        ], ),
                report = '',
                references = {
                    'key' : ''
                    },
                call_ids = [
                    ''
                    ],
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
        )
        """

    def testArtifactDataNotNull(self):
        """Test ArtifactDataNotNull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
