# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_analysis_report import ProjectAnalysisReport

class TestProjectAnalysisReport(unittest.TestCase):
    """ProjectAnalysisReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectAnalysisReport:
        """Test ProjectAnalysisReport
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectAnalysisReport`
        """
        model = ProjectAnalysisReport()
        if include_optional:
            return ProjectAnalysisReport(
                markdown_report = '',
                structured_report = None,
                call_ids = [
                    ''
                    ],
                references = {
                    'key' : ''
                    }
            )
        else:
            return ProjectAnalysisReport(
                markdown_report = '',
                call_ids = [
                    ''
                    ],
                references = {
                    'key' : ''
                    },
        )
        """

    def testProjectAnalysisReport(self):
        """Test ProjectAnalysisReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
