# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_project_share_response import CreateProjectShareResponse

class TestCreateProjectShareResponse(unittest.TestCase):
    """CreateProjectShareResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateProjectShareResponse:
        """Test CreateProjectShareResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateProjectShareResponse`
        """
        model = CreateProjectShareResponse()
        if include_optional:
            return CreateProjectShareResponse(
                share_token = '',
                share_url = '',
                share_entity = keplar_api.models.share_entity.ShareEntity(
                    id = '', 
                    token = '', 
                    entity_kind = 'project', 
                    entity_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    access_count = 1.337, 
                    is_active = True, 
                    created_by_kind = 'participant', 
                    created_by_id = '', 
                    config = null, 
                    email_shares = [
                        keplar_api.models.email_share.EmailShare(
                            id = '', 
                            email = '', 
                            share_entity_id = '', 
                            access_token = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            share_entity = keplar_api.models.share_entity.ShareEntity(
                                id = '', 
                                token = '', 
                                entity_kind = 'project', 
                                entity_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                access_count = 1.337, 
                                is_active = True, 
                                created_by_id = '', 
                                config = null, ), )
                        ], )
            )
        else:
            return CreateProjectShareResponse(
                share_token = '',
                share_url = '',
                share_entity = keplar_api.models.share_entity.ShareEntity(
                    id = '', 
                    token = '', 
                    entity_kind = 'project', 
                    entity_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    access_count = 1.337, 
                    is_active = True, 
                    created_by_kind = 'participant', 
                    created_by_id = '', 
                    config = null, 
                    email_shares = [
                        keplar_api.models.email_share.EmailShare(
                            id = '', 
                            email = '', 
                            share_entity_id = '', 
                            access_token = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            share_entity = keplar_api.models.share_entity.ShareEntity(
                                id = '', 
                                token = '', 
                                entity_kind = 'project', 
                                entity_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                access_count = 1.337, 
                                is_active = True, 
                                created_by_id = '', 
                                config = null, ), )
                        ], ),
        )
        """

    def testCreateProjectShareResponse(self):
        """Test CreateProjectShareResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
