# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.inline_node import InlineNode

class TestInlineNode(unittest.TestCase):
    """InlineNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InlineNode:
        """Test InlineNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InlineNode`
        """
        model = InlineNode()
        if include_optional:
            return InlineNode(
                type = 'text',
                text = '',
                marks = [
                    keplar_api.models.mark.Mark()
                    ],
                attrs = keplar_api.models.mention_node_attrs.MentionNodeAttrs(
                    id = '', 
                    label = '', 
                    type = 'asset', )
            )
        else:
            return InlineNode(
                type = 'text',
                text = '',
        )
        """

    def testInlineNode(self):
        """Test InlineNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
