# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.analyze_notebook200_response_search_results_messages_inner_context_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner

class TestAnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(unittest.TestCase):
    """AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner:
        """Test AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner`
        """
        model = AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner()
        if include_optional:
            return AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(
                role = '',
                message = '',
                index = 1.337,
                seconds_from_start = 1.337,
                duration = 1.337
            )
        else:
            return AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(
                role = '',
                message = '',
                index = 1.337,
        )
        """

    def testAnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner(self):
        """Test AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
