# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.code_invite_config_contacts import CodeInviteConfigContacts

class TestCodeInviteConfigContacts(unittest.TestCase):
    """CodeInviteConfigContacts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CodeInviteConfigContacts:
        """Test CodeInviteConfigContacts
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CodeInviteConfigContacts`
        """
        model = CodeInviteConfigContacts()
        if include_optional:
            return CodeInviteConfigContacts(
                kind = 'CONTACTS',
                is_test = True,
                show_call_metadata = True,
                title = '',
                description = '',
                max_responses = 1.337,
                max_responses_per_participant = 1.337,
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, )
            )
        else:
            return CodeInviteConfigContacts(
                kind = 'CONTACTS',
                title = '',
        )
        """

    def testCodeInviteConfigContacts(self):
        """Test CodeInviteConfigContacts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
