# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.user_search_result import UserSearchResult

class TestUserSearchResult(unittest.TestCase):
    """UserSearchResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserSearchResult:
        """Test UserSearchResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserSearchResult`
        """
        model = UserSearchResult()
        if include_optional:
            return UserSearchResult(
                id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                data = None,
                org_id = '',
                org = keplar_api.models.user_org.UserOrg(
                    id = '', 
                    name = '', ),
                projects = [
                    keplar_api.models.user_project.UserProject(
                        id = '', 
                        name = '', )
                    ],
                default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                    id = '', 
                    name = '', ),
                created_at = ''
            )
        else:
            return UserSearchResult(
                id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                data = None,
                org_id = '',
                org = keplar_api.models.user_org.UserOrg(
                    id = '', 
                    name = '', ),
                projects = [
                    keplar_api.models.user_project.UserProject(
                        id = '', 
                        name = '', )
                    ],
                default_workspace = keplar_api.models.user_default_workspace.UserDefaultWorkspace(
                    id = '', 
                    name = '', ),
                created_at = '',
        )
        """

    def testUserSearchResult(self):
        """Test UserSearchResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
