# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner import ArtifactDataSearchResultTabsInnerMessagesInner

class TestArtifactDataSearchResultTabsInnerMessagesInner(unittest.TestCase):
    """ArtifactDataSearchResultTabsInnerMessagesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataSearchResultTabsInnerMessagesInner:
        """Test ArtifactDataSearchResultTabsInnerMessagesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataSearchResultTabsInnerMessagesInner`
        """
        model = ArtifactDataSearchResultTabsInnerMessagesInner()
        if include_optional:
            return ArtifactDataSearchResultTabsInnerMessagesInner(
                call_id = '',
                project_id = '',
                project_name = '',
                recording_url = '',
                message_index = 1.337,
                message = '',
                score = 1.337,
                context_messages = [
                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                        role = '', 
                        message = '', 
                        index = 1.337, 
                        seconds_from_start = 1.337, 
                        duration = 1.337, )
                    ]
            )
        else:
            return ArtifactDataSearchResultTabsInnerMessagesInner(
                call_id = '',
                project_id = '',
                project_name = '',
                message_index = 1.337,
                message = '',
                score = 1.337,
                context_messages = [
                    keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                        role = '', 
                        message = '', 
                        index = 1.337, 
                        seconds_from_start = 1.337, 
                        duration = 1.337, )
                    ],
        )
        """

    def testArtifactDataSearchResultTabsInnerMessagesInner(self):
        """Test ArtifactDataSearchResultTabsInnerMessagesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
