# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.transcript import Transcript

class TestTranscript(unittest.TestCase):
    """Transcript unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Transcript:
        """Test Transcript
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Transcript`
        """
        model = Transcript()
        if include_optional:
            return Transcript(
                id = '',
                response_id = '',
                messages = [
                    keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                        call_id = '', 
                        index = 1.337, 
                        role = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        message = '', )
                    ],
                attributes = [
                    keplar_api.models.transcript_attributes_inner.Transcript_attributes_inner(
                        label = '', 
                        value = '', )
                    ]
            )
        else:
            return Transcript(
                id = '',
                response_id = '',
                messages = [
                    keplar_api.models.transcript_messages_inner.Transcript_messages_inner(
                        call_id = '', 
                        index = 1.337, 
                        role = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        message = '', )
                    ],
        )
        """

    def testTranscript(self):
        """Test Transcript"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
