# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.api.default_api import DefaultApi


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_user_to_workspace(self) -> None:
        """Test case for add_user_to_workspace

        Add user to a workspace
        """
        pass

    async def test_add_workspace_member(self) -> None:
        """Test case for add_workspace_member

        Add workspace member
        """
        pass

    async def test_analyze_notebook(self) -> None:
        """Test case for analyze_notebook

        Trigger analysis/report generation for a notebook
        """
        pass

    async def test_api_auth_google_get(self) -> None:
        """Test case for api_auth_google_get

        """
        pass

    async def test_api_auth_google_redirect_get(self) -> None:
        """Test case for api_auth_google_redirect_get

        """
        pass

    async def test_api_call_messages_search_post(self) -> None:
        """Test case for api_call_messages_search_post

        Search conversation messages
        """
        pass

    async def test_api_calls_call_id_get(self) -> None:
        """Test case for api_calls_call_id_get

        Get call
        """
        pass

    async def test_api_calls_call_id_messages_index_get(self) -> None:
        """Test case for api_calls_call_id_messages_index_get

        Get conversation message
        """
        pass

    async def test_api_copilotkit_post(self) -> None:
        """Test case for api_copilotkit_post

        """
        pass

    async def test_api_demos_create_demo_invite_post(self) -> None:
        """Test case for api_demos_create_demo_invite_post

        Create demo invite
        """
        pass

    async def test_api_files_file_id_delete(self) -> None:
        """Test case for api_files_file_id_delete

        Delete a file
        """
        pass

    async def test_api_files_file_id_get(self) -> None:
        """Test case for api_files_file_id_get

        Get file metadata
        """
        pass

    async def test_api_files_file_id_signed_url_post(self) -> None:
        """Test case for api_files_file_id_signed_url_post

        Get a signed URL for file access
        """
        pass

    async def test_api_files_post(self) -> None:
        """Test case for api_files_post

        Upload a file
        """
        pass

    async def test_api_invite_code_code_participant_code_participant_code_join_get(self) -> None:
        """Test case for api_invite_code_code_participant_code_participant_code_join_get

        """
        pass

    async def test_api_invite_code_code_start_get(self) -> None:
        """Test case for api_invite_code_code_start_get

        """
        pass

    async def test_api_invites_id_get(self) -> None:
        """Test case for api_invites_id_get

        Get invite
        """
        pass

    async def test_api_invites_id_participant_invites_get(self) -> None:
        """Test case for api_invites_id_participant_invites_get

        Get participant invites
        """
        pass

    async def test_api_invites_id_participant_invites_participant_id_get(self) -> None:
        """Test case for api_invites_id_participant_invites_participant_id_get

        Get participant invite
        """
        pass

    async def test_api_invites_id_participant_invites_participant_id_put(self) -> None:
        """Test case for api_invites_id_participant_invites_participant_id_put

        Update participant invite
        """
        pass

    async def test_api_invites_id_participant_invites_post(self) -> None:
        """Test case for api_invites_id_participant_invites_post

        Create participant invite
        """
        pass

    async def test_api_invites_id_participants_participant_id_call_metadata_get(self) -> None:
        """Test case for api_invites_id_participants_participant_id_call_metadata_get

        Get call metadata by invite ID and participant ID
        """
        pass

    async def test_api_invites_id_put(self) -> None:
        """Test case for api_invites_id_put

        Update invite
        """
        pass

    async def test_api_invites_id_response_attribute_stats_get(self) -> None:
        """Test case for api_invites_id_response_attribute_stats_get

        Get invite response attribute stats
        """
        pass

    async def test_api_invites_id_responses_get(self) -> None:
        """Test case for api_invites_id_responses_get

        Get invite responses
        """
        pass

    async def test_api_invites_id_responses_post(self) -> None:
        """Test case for api_invites_id_responses_post

        Create invite response
        """
        pass

    async def test_api_invites_id_responses_response_id_call_metadata_get(self) -> None:
        """Test case for api_invites_id_responses_response_id_call_metadata_get

        Get call metadata by invite ID and response ID
        """
        pass

    async def test_api_invites_id_responses_response_id_get(self) -> None:
        """Test case for api_invites_id_responses_response_id_get

        Get invite response
        """
        pass

    async def test_api_invites_id_responses_response_id_put(self) -> None:
        """Test case for api_invites_id_responses_response_id_put

        Update invite response
        """
        pass

    async def test_api_invites_post(self) -> None:
        """Test case for api_invites_post

        Create invite
        """
        pass

    async def test_api_projects_draft_get(self) -> None:
        """Test case for api_projects_draft_get

        Get draft project
        """
        pass

    async def test_api_projects_post(self) -> None:
        """Test case for api_projects_post

        Create project
        """
        pass

    async def test_api_projects_project_id_analysis_post(self) -> None:
        """Test case for api_projects_project_id_analysis_post

        Create project analysis
        """
        pass

    async def test_api_projects_project_id_delete_post(self) -> None:
        """Test case for api_projects_project_id_delete_post

        Delete or archive project
        """
        pass

    async def test_api_projects_project_id_files_file_id_delete(self) -> None:
        """Test case for api_projects_project_id_files_file_id_delete

        Remove a file from a project
        """
        pass

    async def test_api_projects_project_id_files_file_id_put(self) -> None:
        """Test case for api_projects_project_id_files_file_id_put

        Update project file metadata
        """
        pass

    async def test_api_projects_project_id_files_get(self) -> None:
        """Test case for api_projects_project_id_files_get

        Get files for a project
        """
        pass

    async def test_api_projects_project_id_files_post(self) -> None:
        """Test case for api_projects_project_id_files_post

        Add an existing file to a project
        """
        pass

    async def test_api_projects_project_id_launch_post(self) -> None:
        """Test case for api_projects_project_id_launch_post

        Launch project
        """
        pass

    async def test_api_projects_project_id_put(self) -> None:
        """Test case for api_projects_project_id_put

        Update project
        """
        pass

    async def test_api_projects_project_id_search_transcripts_post(self) -> None:
        """Test case for api_projects_project_id_search_transcripts_post

        Search project transcripts
        """
        pass

    async def test_api_threads_get(self) -> None:
        """Test case for api_threads_get

        Get threads
        """
        pass

    async def test_api_threads_thread_id_files_get(self) -> None:
        """Test case for api_threads_thread_id_files_get

        Get thread files
        """
        pass

    async def test_api_threads_thread_id_post(self) -> None:
        """Test case for api_threads_thread_id_post

        Upsert thread
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_get(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_get

        Get project brief document versions from thread state history
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_post(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_post

        Create project brief document version from thread state
        """
        pass

    async def test_api_threads_thread_id_project_brief_document_versions_version_put(self) -> None:
        """Test case for api_threads_thread_id_project_brief_document_versions_version_put

        Update a specific project brief document version
        """
        pass

    async def test_api_threads_thread_id_project_brief_versions_get(self) -> None:
        """Test case for api_threads_thread_id_project_brief_versions_get

        Get project brief versions from thread state history
        """
        pass

    async def test_api_threads_thread_id_project_brief_versions_post(self) -> None:
        """Test case for api_threads_thread_id_project_brief_versions_post

        Create project draft versions from thread state history
        """
        pass

    async def test_api_users_id_get(self) -> None:
        """Test case for api_users_id_get

        Get user with configuration
        """
        pass

    async def test_api_vapi_webhook_post(self) -> None:
        """Test case for api_vapi_webhook_post

        """
        pass

    async def test_create_artifact(self) -> None:
        """Test case for create_artifact

        Create artifact
        """
        pass

    async def test_create_code_invite_response(self) -> None:
        """Test case for create_code_invite_response

        Create invite response for invite code
        """
        pass

    async def test_create_code_invite_response_from_existing(self) -> None:
        """Test case for create_code_invite_response_from_existing

        Create invite response from existing response
        """
        pass

    async def test_create_dummy_user(self) -> None:
        """Test case for create_dummy_user

        Create a dummy user for sales demos
        """
        pass

    async def test_create_email_share(self) -> None:
        """Test case for create_email_share

        Add email access to a share
        """
        pass

    async def test_create_notebook(self) -> None:
        """Test case for create_notebook

        Create a new notebook
        """
        pass

    async def test_create_notebook_artifact(self) -> None:
        """Test case for create_notebook_artifact

        Create an empty artifact for a notebook
        """
        pass

    async def test_create_org(self) -> None:
        """Test case for create_org

        Create a new organization
        """
        pass

    async def test_create_project_preview_invite(self) -> None:
        """Test case for create_project_preview_invite

        Create a preview invite for this project based on audienceSettings
        """
        pass

    async def test_create_project_share(self) -> None:
        """Test case for create_project_share

        Create a share link for a project
        """
        pass

    async def test_create_test_participant_code_invite(self) -> None:
        """Test case for create_test_participant_code_invite

        Create test invite for participant
        """
        pass

    async def test_create_transcript_insight_for_code_invite_response(self) -> None:
        """Test case for create_transcript_insight_for_code_invite_response

        Create transcript insight for invite response
        """
        pass

    async def test_create_workspace(self) -> None:
        """Test case for create_workspace

        Create workspace
        """
        pass

    async def test_delete_artifact(self) -> None:
        """Test case for delete_artifact

        Delete artifact
        """
        pass

    async def test_delete_email_share(self) -> None:
        """Test case for delete_email_share

        Remove email access from a share
        """
        pass

    async def test_delete_notebook(self) -> None:
        """Test case for delete_notebook

        Delete a notebook
        """
        pass

    async def test_delete_notebook_artifact_version_group(self) -> None:
        """Test case for delete_notebook_artifact_version_group

        Delete all artifacts in a version group
        """
        pass

    async def test_delete_project_search_index(self) -> None:
        """Test case for delete_project_search_index

        Delete project search index from Qdrant
        """
        pass

    async def test_delete_share_entity(self) -> None:
        """Test case for delete_share_entity

        Delete a share entity
        """
        pass

    async def test_download_invite_responses(self) -> None:
        """Test case for download_invite_responses

        Download invite responses as CSV
        """
        pass

    async def test_download_share_invite_responses(self) -> None:
        """Test case for download_share_invite_responses

        Download invite responses as CSV
        """
        pass

    async def test_generate_presentation_artifact(self) -> None:
        """Test case for generate_presentation_artifact

        Generate presentation via Gamma API for a presentation artifact
        """
        pass

    async def test_get_artifact(self) -> None:
        """Test case for get_artifact

        Get artifact by ID
        """
        pass

    async def test_get_artifact_version_groups(self) -> None:
        """Test case for get_artifact_version_groups

        Get project artifact version groups
        """
        pass

    async def test_get_call_metadata_for_code_invite_response(self) -> None:
        """Test case for get_call_metadata_for_code_invite_response

        Get call metadata for invite response
        """
        pass

    async def test_get_code_invite(self) -> None:
        """Test case for get_code_invite

        Get invite by code
        """
        pass

    async def test_get_code_invite_participant_remaining_responses(self) -> None:
        """Test case for get_code_invite_participant_remaining_responses

        Get remaining responses count for participant
        """
        pass

    async def test_get_code_invite_participant_response(self) -> None:
        """Test case for get_code_invite_participant_response

        Get invite response for participant
        """
        pass

    async def test_get_code_invite_response(self) -> None:
        """Test case for get_code_invite_response

        Get invite response
        """
        pass

    async def test_get_code_invite_response_redirect(self) -> None:
        """Test case for get_code_invite_response_redirect

        Get redirect URL for invite response
        """
        pass

    async def test_get_code_participant_invite(self) -> None:
        """Test case for get_code_participant_invite

        Get participant invite for invite code
        """
        pass

    async def test_get_notebook(self) -> None:
        """Test case for get_notebook

        Get a notebook by ID
        """
        pass

    async def test_get_notebook_artifacts(self) -> None:
        """Test case for get_notebook_artifacts

        Get all artifacts generated from a notebook
        """
        pass

    async def test_get_notebook_projects(self) -> None:
        """Test case for get_notebook_projects

        Get all projects associated with a notebook
        """
        pass

    async def test_get_notebooks(self) -> None:
        """Test case for get_notebooks

        Get all notebooks accessible to user
        """
        pass

    async def test_get_org(self) -> None:
        """Test case for get_org

        Get organization details
        """
        pass

    async def test_get_org_members(self) -> None:
        """Test case for get_org_members

        Get organization members
        """
        pass

    async def test_get_orgs(self) -> None:
        """Test case for get_orgs

        List organizations with stats
        """
        pass

    async def test_get_project(self) -> None:
        """Test case for get_project

        Get project
        """
        pass

    async def test_get_project_artifact(self) -> None:
        """Test case for get_project_artifact

        Get project artifact by ID
        """
        pass

    async def test_get_project_response_attribute_stats(self) -> None:
        """Test case for get_project_response_attribute_stats

        Get project response attribute stats
        """
        pass

    async def test_get_project_responses_metadata(self) -> None:
        """Test case for get_project_responses_metadata

        Get project responses metadata
        """
        pass

    async def test_get_project_shares(self) -> None:
        """Test case for get_project_shares

        Get all shares for a project
        """
        pass

    async def test_get_projects(self) -> None:
        """Test case for get_projects

        Get projects
        """
        pass

    async def test_get_share_entities(self) -> None:
        """Test case for get_share_entities

        List all share entities created by the user
        """
        pass

    async def test_get_shared_artifact(self) -> None:
        """Test case for get_shared_artifact

        Get shared artifact by ID
        """
        pass

    async def test_get_shared_artifact_version_groups(self) -> None:
        """Test case for get_shared_artifact_version_groups

        Get shared project artifacts version groups
        """
        pass

    async def test_get_shared_call(self) -> None:
        """Test case for get_shared_call

        Get shared call data with conversation messages
        """
        pass

    async def test_get_shared_call_metadata(self) -> None:
        """Test case for get_shared_call_metadata

        Get shared call metadata by invite ID and response ID
        """
        pass

    async def test_get_shared_invite_response(self) -> None:
        """Test case for get_shared_invite_response

        Get a single response by ID for a shared invite
        """
        pass

    async def test_get_shared_invite_response_attribute_stats(self) -> None:
        """Test case for get_shared_invite_response_attribute_stats

        Get attribute stats for shared invite responses
        """
        pass

    async def test_get_shared_invite_responses(self) -> None:
        """Test case for get_shared_invite_responses

        Get responses for a shared invite
        """
        pass

    async def test_get_shared_project(self) -> None:
        """Test case for get_shared_project

        Get shared project data
        """
        pass

    async def test_get_shared_project_response_attribute_stats(self) -> None:
        """Test case for get_shared_project_response_attribute_stats

        Get shared project response attribute stats
        """
        pass

    async def test_get_shared_project_responses_metadata(self) -> None:
        """Test case for get_shared_project_responses_metadata

        Get shared project responses metadata
        """
        pass

    async def test_get_user_workspaces(self) -> None:
        """Test case for get_user_workspaces

        Get user workspaces and all available workspaces
        """
        pass

    async def test_get_workspace_members(self) -> None:
        """Test case for get_workspace_members

        Get workspace members
        """
        pass

    async def test_get_workspaces(self) -> None:
        """Test case for get_workspaces

        Get all workspaces
        """
        pass

    async def test_impersonate_user(self) -> None:
        """Test case for impersonate_user

        Impersonate a user
        """
        pass

    async def test_index_project_transcripts(self) -> None:
        """Test case for index_project_transcripts

        Index project transcripts into Qdrant for semantic search
        """
        pass

    async def test_invite_customers(self) -> None:
        """Test case for invite_customers

        Bulk invite customers - creates org/workspace if needed
        """
        pass

    async def test_invite_user(self) -> None:
        """Test case for invite_user

        Send invite to transfer dummy user to customer
        """
        pass

    async def test_join_code_invite(self) -> None:
        """Test case for join_code_invite

        Join invite by code
        """
        pass

    async def test_join_participant_code_invite(self) -> None:
        """Test case for join_participant_code_invite

        Join invite by code and participant code
        """
        pass

    async def test_login(self) -> None:
        """Test case for login

        Login with email and password
        """
        pass

    async def test_logout(self) -> None:
        """Test case for logout

        Logout user
        """
        pass

    async def test_remove_user_from_workspace(self) -> None:
        """Test case for remove_user_from_workspace

        Remove user from a workspace
        """
        pass

    async def test_remove_workspace_member(self) -> None:
        """Test case for remove_workspace_member

        Remove workspace member
        """
        pass

    async def test_request_magic_link(self) -> None:
        """Test case for request_magic_link

        Request magic link for passwordless login
        """
        pass

    async def test_request_password_reset(self) -> None:
        """Test case for request_password_reset

        Request password reset email
        """
        pass

    async def test_request_share_access(self) -> None:
        """Test case for request_share_access

        Request access to a share by email
        """
        pass

    async def test_resend_verification(self) -> None:
        """Test case for resend_verification

        Resend email verification
        """
        pass

    async def test_reset_password(self) -> None:
        """Test case for reset_password

        Reset password with token
        """
        pass

    async def test_save_search(self) -> None:
        """Test case for save_search

        Save search results as a new artifact
        """
        pass

    async def test_search_response_messages(self) -> None:
        """Test case for search_response_messages

        Search response messages by inviteResponseId and messageIndex
        """
        pass

    async def test_search_shared_response_messages(self) -> None:
        """Test case for search_shared_response_messages

        Search shared response messages by responseId and messageIndex
        """
        pass

    async def test_search_users(self) -> None:
        """Test case for search_users

        Search users by email or name
        """
        pass

    async def test_send_user_password_reset(self) -> None:
        """Test case for send_user_password_reset

        Send password reset email to user (admin-triggered)
        """
        pass

    async def test_signup(self) -> None:
        """Test case for signup

        Sign up with email and password
        """
        pass

    async def test_start_call_for_code_invite_response(self) -> None:
        """Test case for start_call_for_code_invite_response

        Start call for invite response
        """
        pass

    async def test_start_phone_call_for_code_invite_response(self) -> None:
        """Test case for start_phone_call_for_code_invite_response

        Start phone call for invite response
        """
        pass

    async def test_update_artifact(self) -> None:
        """Test case for update_artifact

        Update artifact
        """
        pass

    async def test_update_call_for_code_invite_response(self) -> None:
        """Test case for update_call_for_code_invite_response

        Update call for invite response
        """
        pass

    async def test_update_code_invite_response(self) -> None:
        """Test case for update_code_invite_response

        Update invite response
        """
        pass

    async def test_update_notebook(self) -> None:
        """Test case for update_notebook

        Update a notebook
        """
        pass

    async def test_update_notebook_sources(self) -> None:
        """Test case for update_notebook_sources

        Add or remove project sources from a notebook
        """
        pass

    async def test_update_org(self) -> None:
        """Test case for update_org

        Update organization name
        """
        pass

    async def test_update_org2_fa(self) -> None:
        """Test case for update_org2_fa

        Toggle 2FA for organization
        """
        pass

    async def test_update_org_default_workspace(self) -> None:
        """Test case for update_org_default_workspace

        Set/update organization default workspace
        """
        pass

    async def test_update_search(self) -> None:
        """Test case for update_search

        Update existing search artifact
        """
        pass

    async def test_update_share_entity(self) -> None:
        """Test case for update_share_entity

        Update a share entity
        """
        pass

    async def test_update_user_default_workspace(self) -> None:
        """Test case for update_user_default_workspace

        Update user default workspace (auto-adds user if not member)
        """
        pass

    async def test_update_workspace_member(self) -> None:
        """Test case for update_workspace_member

        Update workspace member
        """
        pass

    async def test_upload_call_video(self) -> None:
        """Test case for upload_call_video

        Upload video recording for a call
        """
        pass

    async def test_verify_email(self) -> None:
        """Test case for verify_email

        Verify email address with token
        """
        pass

    async def test_verify_email_access_for_share(self) -> None:
        """Test case for verify_email_access_for_share

        Verify email access for a share
        """
        pass

    async def test_verify_magic_link(self) -> None:
        """Test case for verify_magic_link

        Verify magic link token
        """
        pass


if __name__ == '__main__':
    unittest.main()
