# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_user_default_workspace200_response import UpdateUserDefaultWorkspace200Response

class TestUpdateUserDefaultWorkspace200Response(unittest.TestCase):
    """UpdateUserDefaultWorkspace200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateUserDefaultWorkspace200Response:
        """Test UpdateUserDefaultWorkspace200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateUserDefaultWorkspace200Response`
        """
        model = UpdateUserDefaultWorkspace200Response()
        if include_optional:
            return UpdateUserDefaultWorkspace200Response(
                success = True,
                default_workspace_id = '',
                was_added_to_workspace = True
            )
        else:
            return UpdateUserDefaultWorkspace200Response(
                success = True,
                default_workspace_id = '',
                was_added_to_workspace = True,
        )
        """

    def testUpdateUserDefaultWorkspace200Response(self):
        """Test UpdateUserDefaultWorkspace200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
