# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.panel_settings import PanelSettings

class TestPanelSettings(unittest.TestCase):
    """PanelSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PanelSettings:
        """Test PanelSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PanelSettings`
        """
        model = PanelSettings()
        if include_optional:
            return PanelSettings(
                respondent_attributes = [
                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                        qualifications = [
                            keplar_api.models.panel_qualification.PanelQualification(
                                allowed_option_ids = [
                                    null
                                    ], 
                                question_id = 1.337, )
                            ], 
                        quota = 1.337, 
                        quota_name = '', )
                    ],
                country_code = '',
                language_code = '',
                length_of_interview = 1.337,
                incidence_rate = 1.337,
                compensation = 1.337
            )
        else:
            return PanelSettings(
                respondent_attributes = [
                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                        qualifications = [
                            keplar_api.models.panel_qualification.PanelQualification(
                                allowed_option_ids = [
                                    null
                                    ], 
                                question_id = 1.337, )
                            ], 
                        quota = 1.337, 
                        quota_name = '', )
                    ],
        )
        """

    def testPanelSettings(self):
        """Test PanelSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
