# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.create_code_invite_response_request import CreateCodeInviteResponseRequest

class TestCreateCodeInviteResponseRequest(unittest.TestCase):
    """CreateCodeInviteResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateCodeInviteResponseRequest:
        """Test CreateCodeInviteResponseRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateCodeInviteResponseRequest`
        """
        model = CreateCodeInviteResponseRequest()
        if include_optional:
            return CreateCodeInviteResponseRequest(
                kind = 'VOICE_CALL',
                data = keplar_api.models.invite_response_data.InviteResponseData(
                    email = '', 
                    screener_questions_responses = [
                        keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                            question = '', 
                            response = null, )
                        ], 
                    consented = True, 
                    redirected = True, )
            )
        else:
            return CreateCodeInviteResponseRequest(
        )
        """

    def testCreateCodeInviteResponseRequest(self):
        """Test CreateCodeInviteResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
