# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_projects_project_id_analysis_post200_response import ApiProjectsProjectIdAnalysisPost200Response

class TestApiProjectsProjectIdAnalysisPost200Response(unittest.TestCase):
    """ApiProjectsProjectIdAnalysisPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiProjectsProjectIdAnalysisPost200Response:
        """Test ApiProjectsProjectIdAnalysisPost200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiProjectsProjectIdAnalysisPost200Response`
        """
        model = ApiProjectsProjectIdAnalysisPost200Response()
        if include_optional:
            return ApiProjectsProjectIdAnalysisPost200Response(
                artifact_id = ''
            )
        else:
            return ApiProjectsProjectIdAnalysisPost200Response(
        )
        """

    def testApiProjectsProjectIdAnalysisPost200Response(self):
        """Test ApiProjectsProjectIdAnalysisPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
