# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_participant_invites_post_request import ApiInvitesIdParticipantInvitesPostRequest

class TestApiInvitesIdParticipantInvitesPostRequest(unittest.TestCase):
    """ApiInvitesIdParticipantInvitesPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdParticipantInvitesPostRequest:
        """Test ApiInvitesIdParticipantInvitesPostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdParticipantInvitesPostRequest`
        """
        model = ApiInvitesIdParticipantInvitesPostRequest()
        if include_optional:
            return ApiInvitesIdParticipantInvitesPostRequest(
                participant = keplar_api.models._api_invites__id__participant_invites_post_request_participant._api_invites__id__participantInvites_post_request_participant(
                    id = '', 
                    name = '', 
                    email = '', 
                    phone_number = '01234', 
                    config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                        send_invite_email = True, 
                        show_call_metadata = True, 
                        is_test_invite = True, ), )
            )
        else:
            return ApiInvitesIdParticipantInvitesPostRequest(
                participant = keplar_api.models._api_invites__id__participant_invites_post_request_participant._api_invites__id__participantInvites_post_request_participant(
                    id = '', 
                    name = '', 
                    email = '', 
                    phone_number = '01234', 
                    config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                        send_invite_email = True, 
                        show_call_metadata = True, 
                        is_test_invite = True, ), ),
        )
        """

    def testApiInvitesIdParticipantInvitesPostRequest(self):
        """Test ApiInvitesIdParticipantInvitesPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
