# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_responses_post_request import ApiInvitesIdResponsesPostRequest

class TestApiInvitesIdResponsesPostRequest(unittest.TestCase):
    """ApiInvitesIdResponsesPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdResponsesPostRequest:
        """Test ApiInvitesIdResponsesPostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdResponsesPostRequest`
        """
        model = ApiInvitesIdResponsesPostRequest()
        if include_optional:
            return ApiInvitesIdResponsesPostRequest(
                kind = 'VOICE_CALL',
                participant_invite_code = '',
                data = keplar_api.models.invite_response_data.InviteResponseData(
                    email = '', 
                    screener_questions_responses = [
                        keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                            question = '', 
                            response = null, )
                        ], 
                    consented = True, 
                    redirected = True, )
            )
        else:
            return ApiInvitesIdResponsesPostRequest(
        )
        """

    def testApiInvitesIdResponsesPostRequest(self):
        """Test ApiInvitesIdResponsesPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
