# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_conversation_config import ProjectConversationConfig

class TestProjectConversationConfig(unittest.TestCase):
    """ProjectConversationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectConversationConfig:
        """Test ProjectConversationConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectConversationConfig`
        """
        model = ProjectConversationConfig()
        if include_optional:
            return ProjectConversationConfig(
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
                language = 'en'
            )
        else:
            return ProjectConversationConfig(
                first_message = '',
                end_call_message = '',
                max_duration_seconds = 1.337,
                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                    provider = 'vapi', 
                    voice_id = 'Elliot', ),
        )
        """

    def testProjectConversationConfig(self):
        """Test ProjectConversationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
