# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_response_attribute_data import InviteResponseAttributeData

class TestInviteResponseAttributeData(unittest.TestCase):
    """InviteResponseAttributeData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteResponseAttributeData:
        """Test InviteResponseAttributeData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteResponseAttributeData`
        """
        model = InviteResponseAttributeData()
        if include_optional:
            return InviteResponseAttributeData(
                evidence = keplar_api.models.evidence.Evidence(
                    verbatims = '', 
                    confidence = 1.337, 
                    message_index = 1.337, ),
                observations = [
                    ''
                    ]
            )
        else:
            return InviteResponseAttributeData(
        )
        """

    def testInviteResponseAttributeData(self):
        """Test InviteResponseAttributeData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
