# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.block_content_node import BlockContentNode

class TestBlockContentNode(unittest.TestCase):
    """BlockContentNode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BlockContentNode:
        """Test BlockContentNode
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BlockContentNode`
        """
        model = BlockContentNode()
        if include_optional:
            return BlockContentNode(
                type = 'paragraph',
                content = [
                    keplar_api.models.list_item_node.ListItemNode(
                        type = 'listItem', )
                    ],
                attrs = keplar_api.models.ordered_list_attrs.OrderedListAttrs(
                    start = 1.337, )
            )
        else:
            return BlockContentNode(
                type = 'paragraph',
        )
        """

    def testBlockContentNode(self):
        """Test BlockContentNode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
