# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_customers201_response import InviteCustomers201Response

class TestInviteCustomers201Response(unittest.TestCase):
    """InviteCustomers201Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteCustomers201Response:
        """Test InviteCustomers201Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteCustomers201Response`
        """
        model = InviteCustomers201Response()
        if include_optional:
            return InviteCustomers201Response(
                invited = [
                    keplar_api.models.invited_user.InvitedUser(
                        id = '', 
                        email = '', 
                        name = '', )
                    ],
                org = keplar_api.models.invite_org_result.InviteOrgResult(
                    id = '', 
                    name = '', 
                    domain = '', 
                    is_new = True, ),
                workspace = keplar_api.models.invite_workspace_result.InviteWorkspaceResult(
                    id = '', 
                    name = '', 
                    is_new = True, ),
                skipped = [
                    keplar_api.models.skipped_customer.SkippedCustomer(
                        email = '', 
                        reason = '', )
                    ]
            )
        else:
            return InviteCustomers201Response(
                invited = [
                    keplar_api.models.invited_user.InvitedUser(
                        id = '', 
                        email = '', 
                        name = '', )
                    ],
                org = keplar_api.models.invite_org_result.InviteOrgResult(
                    id = '', 
                    name = '', 
                    domain = '', 
                    is_new = True, ),
                skipped = [
                    keplar_api.models.skipped_customer.SkippedCustomer(
                        email = '', 
                        reason = '', )
                    ],
        )
        """

    def testInviteCustomers201Response(self):
        """Test InviteCustomers201Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
