# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.attribute_stats_schema_inner import AttributeStatsSchemaInner

class TestAttributeStatsSchemaInner(unittest.TestCase):
    """AttributeStatsSchemaInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AttributeStatsSchemaInner:
        """Test AttributeStatsSchemaInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AttributeStatsSchemaInner`
        """
        model = AttributeStatsSchemaInner()
        if include_optional:
            return AttributeStatsSchemaInner(
                kind = keplar_api.models.attribute_stats_schema_inner_kind.AttributeStatsSchema_inner_kind(
                    id = '', 
                    label = '', 
                    description = '', 
                    category = '', 
                    value_kind = 'single', ),
                group = keplar_api.models.attribute_stats_schema_inner_group.AttributeStatsSchema_inner_group(
                    id = '', 
                    purpose = 'screener_response', ),
                values = [
                    keplar_api.models.attribute_stats_schema_inner_values_inner.AttributeStatsSchema_inner_values_inner(
                        id = '', 
                        value = '', 
                        count = 1.337, 
                        total_count = 1.337, )
                    ]
            )
        else:
            return AttributeStatsSchemaInner(
                kind = keplar_api.models.attribute_stats_schema_inner_kind.AttributeStatsSchema_inner_kind(
                    id = '', 
                    label = '', 
                    description = '', 
                    category = '', 
                    value_kind = 'single', ),
                values = [
                    keplar_api.models.attribute_stats_schema_inner_values_inner.AttributeStatsSchema_inner_values_inner(
                        id = '', 
                        value = '', 
                        count = 1.337, 
                        total_count = 1.337, )
                    ],
        )
        """

    def testAttributeStatsSchemaInner(self):
        """Test AttributeStatsSchemaInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
