# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.org_data import OrgData
from typing import Optional, Set
from typing_extensions import Self

class Org(BaseModel):
    """
    Org
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    name: StrictStr
    domain: StrictStr
    data: Optional[OrgData] = None
    default_workspace_id: Optional[StrictStr] = Field(default=None, alias="defaultWorkspaceId")
    users: Optional[List[User]] = None
    default_workspace: Optional[Workspace] = Field(default=None, alias="defaultWorkspace")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "domain", "data", "defaultWorkspaceId", "users", "defaultWorkspace"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Org from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict['users'] = _items
        # override the default output from pydantic by calling `to_dict()` of default_workspace
        if self.default_workspace:
            _dict['defaultWorkspace'] = self.default_workspace.to_dict()
        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if default_workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace_id is None and "default_workspace_id" in self.model_fields_set:
            _dict['defaultWorkspaceId'] = None

        # set to None if default_workspace (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace is None and "default_workspace" in self.model_fields_set:
            _dict['defaultWorkspace'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Org from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "domain": obj.get("domain"),
            "data": OrgData.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "defaultWorkspaceId": obj.get("defaultWorkspaceId"),
            "users": [User.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "defaultWorkspace": Workspace.from_dict(obj["defaultWorkspace"]) if obj.get("defaultWorkspace") is not None else None
        })
        return _obj

from keplar_api.models.user import User
from keplar_api.models.workspace import Workspace
# TODO: Rewrite to not use raise_errors
Org.model_rebuild(raise_errors=False)

