# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_summary_with_analytics import ProjectSummaryWithAnalytics

class TestProjectSummaryWithAnalytics(unittest.TestCase):
    """ProjectSummaryWithAnalytics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectSummaryWithAnalytics:
        """Test ProjectSummaryWithAnalytics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectSummaryWithAnalytics`
        """
        model = ProjectSummaryWithAnalytics()
        if include_optional:
            return ProjectSummaryWithAnalytics(
                id = '',
                name = '',
                description = '',
                status = 'ACTIVE',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                config = keplar_api.models.project_config.ProjectConfig(
                    project_kind = 'custom', 
                    prompt_variables = {
                        'key' : null
                        }, 
                    learning_plan = '', 
                    brief = keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], ), 
                    current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', ), 
                    brief_document = '', 
                    screener_questions = [
                        keplar_api.models.screener_question.ScreenerQuestion()
                        ], 
                    audience_settings = keplar_api.models.project_audience.ProjectAudience(
                        sample_size = 1.337, 
                        invite_title = '', 
                        invite_description = '', 
                        participants = [
                            keplar_api.models.participant_create.ParticipantCreate(
                                id = '', 
                                name = '', 
                                email = '', 
                                phone_number = '01234', 
                                data = keplar_api.models.data.data(), )
                            ], 
                        panel_settings = keplar_api.models.panel_settings.PanelSettings(
                            respondent_attributes = [
                                keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                    qualifications = [
                                        keplar_api.models.panel_qualification.PanelQualification(
                                            allowed_option_ids = [
                                                null
                                                ], 
                                            question_id = 1.337, )
                                        ], 
                                    quota = 1.337, 
                                    quota_name = '', )
                                ], 
                            country_code = '', 
                            language_code = '', 
                            length_of_interview = 1.337, 
                            incidence_rate = 1.337, 
                            compensation = 1.337, ), 
                        use_public_link = True, ), ),
                invites = [
                    keplar_api.models.invite_with_analytics.InviteWithAnalytics()
                    ]
            )
        else:
            return ProjectSummaryWithAnalytics(
                id = '',
                name = '',
                status = 'ACTIVE',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                config = keplar_api.models.project_config.ProjectConfig(
                    project_kind = 'custom', 
                    prompt_variables = {
                        'key' : null
                        }, 
                    learning_plan = '', 
                    brief = keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], ), 
                    current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', ), 
                    brief_document = '', 
                    screener_questions = [
                        keplar_api.models.screener_question.ScreenerQuestion()
                        ], 
                    audience_settings = keplar_api.models.project_audience.ProjectAudience(
                        sample_size = 1.337, 
                        invite_title = '', 
                        invite_description = '', 
                        participants = [
                            keplar_api.models.participant_create.ParticipantCreate(
                                id = '', 
                                name = '', 
                                email = '', 
                                phone_number = '01234', 
                                data = keplar_api.models.data.data(), )
                            ], 
                        panel_settings = keplar_api.models.panel_settings.PanelSettings(
                            respondent_attributes = [
                                keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                    qualifications = [
                                        keplar_api.models.panel_qualification.PanelQualification(
                                            allowed_option_ids = [
                                                null
                                                ], 
                                            question_id = 1.337, )
                                        ], 
                                    quota = 1.337, 
                                    quota_name = '', )
                                ], 
                            country_code = '', 
                            language_code = '', 
                            length_of_interview = 1.337, 
                            incidence_rate = 1.337, 
                            compensation = 1.337, ), 
                        use_public_link = True, ), ),
                invites = [
                    keplar_api.models.invite_with_analytics.InviteWithAnalytics()
                    ],
        )
        """

    def testProjectSummaryWithAnalytics(self):
        """Test ProjectSummaryWithAnalytics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
