# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.screener_question_choose_multiple_public import ScreenerQuestionChooseMultiplePublic

class TestScreenerQuestionChooseMultiplePublic(unittest.TestCase):
    """ScreenerQuestionChooseMultiplePublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScreenerQuestionChooseMultiplePublic:
        """Test ScreenerQuestionChooseMultiplePublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScreenerQuestionChooseMultiplePublic`
        """
        model = ScreenerQuestionChooseMultiplePublic()
        if include_optional:
            return ScreenerQuestionChooseMultiplePublic(
                type = 'chooseMultiple',
                question = '',
                image_file_id = '',
                options = {
                    'key' : keplar_api.models.screener_question_choose_multiple_options_value.ScreenerQuestionChooseMultiple_options_value(
                        option_text = '', 
                        option_kind = 'neutral', 
                        index = 0, )
                    },
                randomize_order = True,
                show_select_all_of_above = True,
                show_select_none_of_above = True,
                image_url = ''
            )
        else:
            return ScreenerQuestionChooseMultiplePublic(
                type = 'chooseMultiple',
                question = '',
                options = {
                    'key' : keplar_api.models.screener_question_choose_multiple_options_value.ScreenerQuestionChooseMultiple_options_value(
                        option_text = '', 
                        option_kind = 'neutral', 
                        index = 0, )
                    },
                show_select_all_of_above = True,
                show_select_none_of_above = True,
        )
        """

    def testScreenerQuestionChooseMultiplePublic(self):
        """Test ScreenerQuestionChooseMultiplePublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
