# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_orgs200_response_items_inner import GetOrgs200ResponseItemsInner

class TestGetOrgs200ResponseItemsInner(unittest.TestCase):
    """GetOrgs200ResponseItemsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetOrgs200ResponseItemsInner:
        """Test GetOrgs200ResponseItemsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetOrgs200ResponseItemsInner`
        """
        model = GetOrgs200ResponseItemsInner()
        if include_optional:
            return GetOrgs200ResponseItemsInner(
                id = '',
                name = '',
                domain = '',
                is2_fa_enabled = True,
                default_workspace_id = '',
                default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                    id = '', 
                    name = '', ),
                stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                    total_projects = 1.337, 
                    total_responses_completed = 1.337, 
                    total_responses = 1.337, 
                    total_members = 1.337, 
                    last_activity_at = '', ),
                created_at = '',
                updated_at = ''
            )
        else:
            return GetOrgs200ResponseItemsInner(
                id = '',
                name = '',
                domain = '',
                is2_fa_enabled = True,
                default_workspace_id = '',
                default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                    id = '', 
                    name = '', ),
                stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                    total_projects = 1.337, 
                    total_responses_completed = 1.337, 
                    total_responses = 1.337, 
                    total_members = 1.337, 
                    last_activity_at = '', ),
                created_at = '',
                updated_at = '',
        )
        """

    def testGetOrgs200ResponseItemsInner(self):
        """Test GetOrgs200ResponseItemsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
