# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_participant_invites_post_request_participant import ApiInvitesIdParticipantInvitesPostRequestParticipant

class TestApiInvitesIdParticipantInvitesPostRequestParticipant(unittest.TestCase):
    """ApiInvitesIdParticipantInvitesPostRequestParticipant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdParticipantInvitesPostRequestParticipant:
        """Test ApiInvitesIdParticipantInvitesPostRequestParticipant
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdParticipantInvitesPostRequestParticipant`
        """
        model = ApiInvitesIdParticipantInvitesPostRequestParticipant()
        if include_optional:
            return ApiInvitesIdParticipantInvitesPostRequestParticipant(
                id = '',
                name = '',
                email = '',
                phone_number = '01234',
                config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                    send_invite_email = True, 
                    show_call_metadata = True, 
                    is_test_invite = True, )
            )
        else:
            return ApiInvitesIdParticipantInvitesPostRequestParticipant(
        )
        """

    def testApiInvitesIdParticipantInvitesPostRequestParticipant(self):
        """Test ApiInvitesIdParticipantInvitesPostRequestParticipant"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
