# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_notebook_request_config import UpdateNotebookRequestConfig

class TestUpdateNotebookRequestConfig(unittest.TestCase):
    """UpdateNotebookRequestConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateNotebookRequestConfig:
        """Test UpdateNotebookRequestConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateNotebookRequestConfig`
        """
        model = UpdateNotebookRequestConfig()
        if include_optional:
            return UpdateNotebookRequestConfig(
                sources = [
                    ''
                    ],
                mode = 'report',
                settings = None
            )
        else:
            return UpdateNotebookRequestConfig(
                sources = [
                    ''
                    ],
                mode = 'report',
        )
        """

    def testUpdateNotebookRequestConfig(self):
        """Test UpdateNotebookRequestConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
