# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_demos_create_demo_invite_post_request import ApiDemosCreateDemoInvitePostRequest

class TestApiDemosCreateDemoInvitePostRequest(unittest.TestCase):
    """ApiDemosCreateDemoInvitePostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiDemosCreateDemoInvitePostRequest:
        """Test ApiDemosCreateDemoInvitePostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiDemosCreateDemoInvitePostRequest`
        """
        model = ApiDemosCreateDemoInvitePostRequest()
        if include_optional:
            return ApiDemosCreateDemoInvitePostRequest(
                name = '',
                company = '',
                email = '',
                invite_code = ''
            )
        else:
            return ApiDemosCreateDemoInvitePostRequest(
                name = '',
                company = '',
                email = '',
                invite_code = '',
        )
        """

    def testApiDemosCreateDemoInvitePostRequest(self):
        """Test ApiDemosCreateDemoInvitePostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
