# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_customers_request import InviteCustomersRequest

class TestInviteCustomersRequest(unittest.TestCase):
    """InviteCustomersRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteCustomersRequest:
        """Test InviteCustomersRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteCustomersRequest`
        """
        model = InviteCustomersRequest()
        if include_optional:
            return InviteCustomersRequest(
                customers = [
                    keplar_api.models.invite_customer_item.InviteCustomerItem(
                        email = '', 
                        name = '0', )
                    ],
                org_name = '0',
                is2_fa_enabled = True,
                default_workspace_id = '',
                create_default_workspace = '0',
                additional_workspace_ids = [
                    ''
                    ]
            )
        else:
            return InviteCustomersRequest(
                customers = [
                    keplar_api.models.invite_customer_item.InviteCustomerItem(
                        email = '', 
                        name = '0', )
                    ],
        )
        """

    def testInviteCustomersRequest(self):
        """Test InviteCustomersRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
