# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.byo_panel_repdata_config import ByoPanelRepdataConfig

class TestByoPanelRepdataConfig(unittest.TestCase):
    """ByoPanelRepdataConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ByoPanelRepdataConfig:
        """Test ByoPanelRepdataConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ByoPanelRepdataConfig`
        """
        model = ByoPanelRepdataConfig()
        if include_optional:
            return ByoPanelRepdataConfig(
                kind = 'REPDATA',
                selected_qualifications = [
                    keplar_api.models.repdata_qualification.RepdataQualification(
                        question_id = 1.337, 
                        allowed_option_ids = [
                            null
                            ], )
                    ]
            )
        else:
            return ByoPanelRepdataConfig(
                kind = 'REPDATA',
                selected_qualifications = [
                    keplar_api.models.repdata_qualification.RepdataQualification(
                        question_id = 1.337, 
                        allowed_option_ids = [
                            null
                            ], )
                    ],
        )
        """

    def testByoPanelRepdataConfig(self):
        """Test ByoPanelRepdataConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
