# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.user_account_status import UserAccountStatus
from keplar_api.models.user_default_workspace import UserDefaultWorkspace
from keplar_api.models.user_org import UserOrg
from keplar_api.models.user_project import UserProject
from typing import Optional, Set
from typing_extensions import Self

class UserSearchResult(BaseModel):
    """
    UserSearchResult
    """ # noqa: E501
    id: StrictStr
    email: StrictStr
    name: StrictStr
    account_status: UserAccountStatus = Field(alias="accountStatus")
    data: Optional[Any]
    org_id: Optional[StrictStr] = Field(alias="orgId")
    org: Optional[UserOrg]
    projects: List[UserProject]
    default_workspace: Optional[UserDefaultWorkspace] = Field(alias="defaultWorkspace")
    created_at: StrictStr = Field(alias="createdAt")
    __properties: ClassVar[List[str]] = ["id", "email", "name", "accountStatus", "data", "orgId", "org", "projects", "defaultWorkspace", "createdAt"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserSearchResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of org
        if self.org:
            _dict['org'] = self.org.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in projects (list)
        _items = []
        if self.projects:
            for _item_projects in self.projects:
                if _item_projects:
                    _items.append(_item_projects.to_dict())
            _dict['projects'] = _items
        # override the default output from pydantic by calling `to_dict()` of default_workspace
        if self.default_workspace:
            _dict['defaultWorkspace'] = self.default_workspace.to_dict()
        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if org_id (nullable) is None
        # and model_fields_set contains the field
        if self.org_id is None and "org_id" in self.model_fields_set:
            _dict['orgId'] = None

        # set to None if org (nullable) is None
        # and model_fields_set contains the field
        if self.org is None and "org" in self.model_fields_set:
            _dict['org'] = None

        # set to None if default_workspace (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace is None and "default_workspace" in self.model_fields_set:
            _dict['defaultWorkspace'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserSearchResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "email": obj.get("email"),
            "name": obj.get("name"),
            "accountStatus": obj.get("accountStatus"),
            "data": obj.get("data"),
            "orgId": obj.get("orgId"),
            "org": UserOrg.from_dict(obj["org"]) if obj.get("org") is not None else None,
            "projects": [UserProject.from_dict(_item) for _item in obj["projects"]] if obj.get("projects") is not None else None,
            "defaultWorkspace": UserDefaultWorkspace.from_dict(obj["defaultWorkspace"]) if obj.get("defaultWorkspace") is not None else None,
            "createdAt": obj.get("createdAt")
        })
        return _obj


