# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.user import User

class TestUser(unittest.TestCase):
    """User unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> User:
        """Test User
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `User`
        """
        model = User()
        if include_optional:
            return User(
                id = '',
                seq = 1.337,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                provider = 'google',
                user_id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                location = '',
                profile_image_url = '',
                data = keplar_api.models.user_data.UserData(
                    launch_trial = True, 
                    admin_level = 'ADMIN', 
                    is_dummy = True, ),
                password_hash = '',
                email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                token = '',
                token_kind = 'email_verification',
                token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                org_id = '',
                default_workspace_id = '',
                org = keplar_api.models.org.Org(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    name = '', 
                    domain = '', 
                    data = keplar_api.models.org_data.OrgData(
                        is2_fa_enabled = True, ), 
                    default_workspace_id = '', 
                    users = [
                        keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            default_workspace = keplar_api.models.workspace.Workspace(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                projects = [
                                    keplar_api.models.project.Project(
                                        id = '', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        name = '', 
                                        description = '', 
                                        status = 'ACTIVE', 
                                        created_by_id = '', 
                                        workspace_id = '', 
                                        moderator_id = '', 
                                        config = keplar_api.models.project_config.ProjectConfig(
                                            project_kind = 'custom', 
                                            prompt_variables = {
                                                'key' : null
                                                }, 
                                            learning_plan = '', 
                                            brief = keplar_api.models.project_brief.ProjectBrief(
                                                title = '', 
                                                objective = '', 
                                                learning_goals = '', 
                                                key_questions = '', 
                                                conversation_flow = [
                                                    ''
                                                    ], 
                                                rules = [
                                                    ''
                                                    ], 
                                                assets = [
                                                    ''
                                                    ], ), 
                                            current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                doc = keplar_api.models.brief_document.BriefDocument(
                                                    type = 'doc', 
                                                    content = [
                                                        keplar_api.models.content_node.ContentNode()
                                                        ], ), 
                                                version = 1.337, 
                                                created_at = '', 
                                                updated_at = '', ), 
                                            brief_document = '', 
                                            screener_questions = [
                                                keplar_api.models.screener_question.ScreenerQuestion()
                                                ], 
                                            audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                sample_size = 1.337, 
                                                invite_title = '', 
                                                invite_description = '', 
                                                participants = [
                                                    keplar_api.models.participant_create.ParticipantCreate(
                                                        id = '', 
                                                        name = '', 
                                                        email = '', 
                                                        phone_number = '01234', )
                                                    ], 
                                                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                    respondent_attributes = [
                                                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                            qualifications = [
                                                                keplar_api.models.panel_qualification.PanelQualification(
                                                                    allowed_option_ids = [
                                                                        null
                                                                        ], 
                                                                    question_id = 1.337, )
                                                                ], 
                                                            quota = 1.337, 
                                                            quota_name = '', )
                                                        ], 
                                                    country_code = '', 
                                                    language_code = '', 
                                                    length_of_interview = 1.337, 
                                                    incidence_rate = 1.337, 
                                                    compensation = 1.337, ), 
                                                use_public_link = True, ), ), 
                                        conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                            first_message = '', 
                                            end_call_message = '', 
                                            max_duration_seconds = 1.337, 
                                            voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                provider = 'vapi', 
                                                voice_id = 'Elliot', ), 
                                            language = 'en', ), 
                                        analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                            report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                markdown_report = '', 
                                                structured_report = null, 
                                                call_ids = [
                                                    ''
                                                    ], 
                                                references = {
                                                    'key' : ''
                                                    }, ), ), 
                                        created_by = keplar_api.models.user.User(
                                            id = '', 
                                            seq = 1.337, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            provider = 'google', 
                                            user_id = '', 
                                            email = '', 
                                            name = '', 
                                            account_status = 'ACTIVE', 
                                            location = '', 
                                            profile_image_url = '', 
                                            password_hash = '', 
                                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            token = '', 
                                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            org_id = '', 
                                            default_workspace_id = '', 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', 
                                                    user = , 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), )
                                                ], 
                                            invites = [
                                                
                                                ], 
                                            chat_sessions = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            uploaded_files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_group = [
                                                
                                                ], 
                                            artifact = [
                                                
                                                ], 
                                            notebooks = [
                                                
                                                ], ), 
                                        workspace = , 
                                        moderator = , 
                                        invites = , 
                                        chat_sessions = , 
                                        project_files = [
                                            keplar_api.models.project_file.ProjectFile(
                                                id = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                project_id = '', 
                                                file_id = '', 
                                                description = '', )
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifacts = , 
                                        artifact_version_group = [
                                            
                                            ], )
                                    ], 
                                participants = [
                                    
                                    ], 
                                moderators = , 
                                files = [
                                    
                                    ], 
                                threads = , 
                                attribute_kind_groups = [
                                    
                                    ], 
                                workspace_members = [
                                    keplar_api.models.workspace_member.WorkspaceMember(
                                        id = '', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        role = 'owner', 
                                        user_id = '', 
                                        workspace_id = '', )
                                    ], 
                                notebooks = , 
                                default_for_users = [
                                    
                                    ], 
                                default_for_orgs = [
                                    
                                    ], ), 
                            workspace_members = , 
                            projects = [
                                
                                ], 
                            invites = , 
                            chat_sessions = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , )
                        ], 
                    default_workspace = , ),
                default_workspace = keplar_api.models.workspace.Workspace(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    name = '', 
                    projects = [
                        keplar_api.models.project.Project(
                            id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            description = '', 
                            status = 'ACTIVE', 
                            created_by_id = '', 
                            workspace_id = '', 
                            moderator_id = '', 
                            config = keplar_api.models.project_config.ProjectConfig(
                                project_kind = 'custom', 
                                prompt_variables = {
                                    'key' : null
                                    }, 
                                learning_plan = '', 
                                brief = keplar_api.models.project_brief.ProjectBrief(
                                    title = '', 
                                    objective = '', 
                                    learning_goals = '', 
                                    key_questions = '', 
                                    conversation_flow = [
                                        ''
                                        ], 
                                    rules = [
                                        ''
                                        ], 
                                    assets = [
                                        ''
                                        ], ), 
                                current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                    doc = keplar_api.models.brief_document.BriefDocument(
                                        type = 'doc', 
                                        content = [
                                            keplar_api.models.content_node.ContentNode()
                                            ], ), 
                                    version = 1.337, 
                                    created_at = '', 
                                    updated_at = '', ), 
                                brief_document = '', 
                                screener_questions = [
                                    keplar_api.models.screener_question.ScreenerQuestion()
                                    ], 
                                audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                    sample_size = 1.337, 
                                    invite_title = '', 
                                    invite_description = '', 
                                    participants = [
                                        keplar_api.models.participant_create.ParticipantCreate(
                                            id = '', 
                                            name = '', 
                                            email = '', 
                                            phone_number = '01234', 
                                            data = keplar_api.models.data.data(), )
                                        ], 
                                    panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                        respondent_attributes = [
                                            keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                qualifications = [
                                                    keplar_api.models.panel_qualification.PanelQualification(
                                                        allowed_option_ids = [
                                                            null
                                                            ], 
                                                        question_id = 1.337, )
                                                    ], 
                                                quota = 1.337, 
                                                quota_name = '', )
                                            ], 
                                        country_code = '', 
                                        language_code = '', 
                                        length_of_interview = 1.337, 
                                        incidence_rate = 1.337, 
                                        compensation = 1.337, ), 
                                    use_public_link = True, ), ), 
                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                first_message = '', 
                                end_call_message = '', 
                                max_duration_seconds = 1.337, 
                                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                    provider = 'vapi', 
                                    voice_id = 'Elliot', ), 
                                language = 'en', ), 
                            analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                    markdown_report = '', 
                                    structured_report = null, 
                                    call_ids = [
                                        ''
                                        ], 
                                    references = {
                                        'key' : ''
                                        }, ), ), 
                            created_by = keplar_api.models.user.User(
                                id = '', 
                                seq = 1.337, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                provider = 'google', 
                                user_id = '', 
                                email = '', 
                                name = '', 
                                account_status = 'ACTIVE', 
                                location = '', 
                                profile_image_url = '', 
                                data = keplar_api.models.user_data.UserData(
                                    launch_trial = True, 
                                    admin_level = 'ADMIN', 
                                    is_dummy = True, ), 
                                password_hash = '', 
                                email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                token = '', 
                                token_kind = 'email_verification', 
                                token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                org_id = '', 
                                default_workspace_id = '', 
                                org = keplar_api.models.org.Org(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    domain = '', 
                                    default_workspace_id = '', 
                                    users = [
                                        keplar_api.models.user.User(
                                            id = '', 
                                            seq = 1.337, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            provider = 'google', 
                                            user_id = '', 
                                            email = '', 
                                            name = '', 
                                            account_status = 'ACTIVE', 
                                            location = '', 
                                            profile_image_url = '', 
                                            password_hash = '', 
                                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            token = '', 
                                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            org_id = '', 
                                            default_workspace_id = '', 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', 
                                                    user = , 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), )
                                                ], 
                                            invites = [
                                                
                                                ], 
                                            chat_sessions = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            uploaded_files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_group = [
                                                
                                                ], 
                                            artifact = [
                                                
                                                ], 
                                            notebooks = [
                                                
                                                ], )
                                        ], ), 
                                workspace_members = [
                                    keplar_api.models.workspace_member.WorkspaceMember(
                                        id = '', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        role = 'owner', 
                                        user_id = '', 
                                        workspace_id = '', )
                                    ], 
                                invites = , 
                                chat_sessions = , 
                                moderators = , 
                                uploaded_files = [
                                    
                                    ], 
                                threads = , 
                                attribute_kind_group = , 
                                artifact = [
                                    
                                    ], 
                                notebooks = , ), 
                            workspace = , 
                            moderator = , 
                            invites = , 
                            chat_sessions = , 
                            project_files = [
                                keplar_api.models.project_file.ProjectFile(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    project_id = '', 
                                    file_id = '', 
                                    description = '', )
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifacts = , 
                            artifact_version_group = [
                                
                                ], )
                        ], 
                    participants = [
                        
                        ], 
                    moderators = , 
                    files = [
                        
                        ], 
                    threads = , 
                    attribute_kind_groups = [
                        
                        ], 
                    workspace_members = , 
                    notebooks = , 
                    default_for_users = [
                        
                        ], 
                    default_for_orgs = [
                        
                        ], ),
                workspace_members = [
                    keplar_api.models.workspace_member.WorkspaceMember(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        role = 'owner', 
                        user_id = '', 
                        workspace_id = '', 
                        user = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            projects = [
                                                keplar_api.models.project.Project(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    name = '', 
                                                    description = '', 
                                                    status = 'ACTIVE', 
                                                    created_by_id = '', 
                                                    workspace_id = '', 
                                                    moderator_id = '', 
                                                    config = keplar_api.models.project_config.ProjectConfig(
                                                        project_kind = 'custom', 
                                                        prompt_variables = {
                                                            'key' : null
                                                            }, 
                                                        learning_plan = '', 
                                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                                            title = '', 
                                                            objective = '', 
                                                            learning_goals = '', 
                                                            key_questions = '', 
                                                            conversation_flow = [
                                                                ''
                                                                ], 
                                                            rules = [
                                                                ''
                                                                ], 
                                                            assets = [
                                                                ''
                                                                ], ), 
                                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                                type = 'doc', 
                                                                content = [
                                                                    keplar_api.models.content_node.ContentNode()
                                                                    ], ), 
                                                            version = 1.337, 
                                                            created_at = '', 
                                                            updated_at = '', ), 
                                                        brief_document = '', 
                                                        screener_questions = [
                                                            keplar_api.models.screener_question.ScreenerQuestion()
                                                            ], 
                                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                            sample_size = 1.337, 
                                                            invite_title = '', 
                                                            invite_description = '', 
                                                            participants = [
                                                                keplar_api.models.participant_create.ParticipantCreate(
                                                                    id = '', 
                                                                    name = '', 
                                                                    email = '', 
                                                                    phone_number = '01234', )
                                                                ], 
                                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                respondent_attributes = [
                                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                        qualifications = [
                                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                                allowed_option_ids = [
                                                                                    null
                                                                                    ], 
                                                                                question_id = 1.337, )
                                                                            ], 
                                                                        quota = 1.337, 
                                                                        quota_name = '', )
                                                                    ], 
                                                                country_code = '', 
                                                                language_code = '', 
                                                                length_of_interview = 1.337, 
                                                                incidence_rate = 1.337, 
                                                                compensation = 1.337, ), 
                                                            use_public_link = True, ), ), 
                                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        language = 'en', ), 
                                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                            markdown_report = '', 
                                                            structured_report = null, 
                                                            call_ids = [
                                                                ''
                                                                ], 
                                                            references = {
                                                                'key' : ''
                                                                }, ), ), 
                                                    created_by = , 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    moderator = , 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    project_files = [
                                                        keplar_api.models.project_file.ProjectFile(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            project_id = '', 
                                                            file_id = '', 
                                                            description = '', )
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifacts = , 
                                                    artifact_version_group = [
                                                        
                                                        ], )
                                                ], 
                                            participants = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        projects = [
                                            
                                            ], 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            projects = , 
                            invites = , 
                            chat_sessions = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        workspace = , )
                    ],
                projects = [
                    keplar_api.models.project.Project(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        description = '', 
                        status = 'ACTIVE', 
                        created_by_id = '', 
                        workspace_id = '', 
                        moderator_id = '', 
                        config = keplar_api.models.project_config.ProjectConfig(
                            project_kind = 'custom', 
                            prompt_variables = {
                                'key' : null
                                }, 
                            learning_plan = '', 
                            brief = keplar_api.models.project_brief.ProjectBrief(
                                title = '', 
                                objective = '', 
                                learning_goals = '', 
                                key_questions = '', 
                                conversation_flow = [
                                    ''
                                    ], 
                                rules = [
                                    ''
                                    ], 
                                assets = [
                                    ''
                                    ], ), 
                            current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                doc = keplar_api.models.brief_document.BriefDocument(
                                    type = 'doc', 
                                    content = [
                                        keplar_api.models.content_node.ContentNode()
                                        ], ), 
                                version = 1.337, 
                                created_at = '', 
                                updated_at = '', ), 
                            brief_document = '', 
                            screener_questions = [
                                keplar_api.models.screener_question.ScreenerQuestion()
                                ], 
                            audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                sample_size = 1.337, 
                                invite_title = '', 
                                invite_description = '', 
                                participants = [
                                    keplar_api.models.participant_create.ParticipantCreate(
                                        id = '', 
                                        name = '', 
                                        email = '', 
                                        phone_number = '01234', 
                                        data = keplar_api.models.data.data(), )
                                    ], 
                                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                    respondent_attributes = [
                                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                            qualifications = [
                                                keplar_api.models.panel_qualification.PanelQualification(
                                                    allowed_option_ids = [
                                                        null
                                                        ], 
                                                    question_id = 1.337, )
                                                ], 
                                            quota = 1.337, 
                                            quota_name = '', )
                                        ], 
                                    country_code = '', 
                                    language_code = '', 
                                    length_of_interview = 1.337, 
                                    incidence_rate = 1.337, 
                                    compensation = 1.337, ), 
                                use_public_link = True, ), ), 
                        conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                            first_message = '', 
                            end_call_message = '', 
                            max_duration_seconds = 1.337, 
                            voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                provider = 'vapi', 
                                voice_id = 'Elliot', ), 
                            language = 'en', ), 
                        analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                            report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                markdown_report = '', 
                                structured_report = null, 
                                call_ids = [
                                    ''
                                    ], 
                                references = {
                                    'key' : ''
                                    }, ), ), 
                        created_by = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            moderators = [
                                                keplar_api.models.moderator.Moderator(
                                                    id = '', 
                                                    name = '', 
                                                    description = '', 
                                                    visibility = 'public', 
                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                        system_prompt = '', 
                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                            provider = 'openai', 
                                                            model = 'gpt-4.1', ), 
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        tools = [
                                                            keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                type = 'function', 
                                                                function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                    name = '', 
                                                                    description = '', 
                                                                    parameters = {
                                                                        'key' : null
                                                                        }, ), )
                                                            ], ), 
                                                    vendor = 'vapi', 
                                                    vendor_id = '', 
                                                    vendor_data = null, 
                                                    workspace_id = '', 
                                                    created_by_id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    parent_moderator_id = '', 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = keplar_api.models.moderator.Moderator(
                                                                                id = '', 
                                                                                name = '', 
                                                                                description = '', 
                                                                                visibility = 'public', 
                                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                                    system_prompt = '', 
                                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                        provider = 'openai', 
                                                                                        model = 'gpt-4.1', ), 
                                                                                    first_message = '', 
                                                                                    end_call_message = '', 
                                                                                    max_duration_seconds = 1.337, 
                                                                                    voice = , ), 
                                                                                vendor = 'vapi', 
                                                                                vendor_id = '', 
                                                                                vendor_data = null, 
                                                                                workspace_id = '', 
                                                                                created_by_id = '', 
                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                parent_moderator_id = '', 
                                                                                parent_moderator = , 
                                                                                child_moderators = [
                                                                                    
                                                                                    ], ), 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    parent_moderator = , 
                                                    child_moderators = [
                                                        
                                                        ], )
                                                ], 
                                            files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', )
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        workspace_members = , 
                                        invites = [
                                            
                                            ], 
                                        chat_sessions = [
                                            
                                            ], 
                                        moderators = [
                                            
                                            ], 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = [
                                            
                                            ], 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            workspace_members = , 
                            invites = , 
                            chat_sessions = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        workspace = , 
                        moderator = , 
                        invites = , 
                        chat_sessions = , 
                        project_files = [
                            keplar_api.models.project_file.ProjectFile(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                project_id = '', 
                                file_id = '', 
                                description = '', )
                            ], 
                        threads = , 
                        attribute_kind_group = , 
                        artifacts = , 
                        artifact_version_group = [
                            
                            ], )
                    ],
                invites = [
                    keplar_api.models.invite.Invite(
                        id = '', 
                        name = '', 
                        description = '', 
                        config = keplar_api.models.invite_config.InviteConfig(), 
                        code = '', 
                        status = 'PREVIEW', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by_id = '', 
                        project_id = '', 
                        created_by = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            projects = [
                                                keplar_api.models.project.Project(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    name = '', 
                                                    description = '', 
                                                    status = 'ACTIVE', 
                                                    created_by_id = '', 
                                                    workspace_id = '', 
                                                    moderator_id = '', 
                                                    config = keplar_api.models.project_config.ProjectConfig(
                                                        project_kind = 'custom', 
                                                        prompt_variables = {
                                                            'key' : null
                                                            }, 
                                                        learning_plan = '', 
                                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                                            title = '', 
                                                            objective = '', 
                                                            learning_goals = '', 
                                                            key_questions = '', 
                                                            conversation_flow = [
                                                                ''
                                                                ], 
                                                            rules = [
                                                                ''
                                                                ], 
                                                            assets = [
                                                                ''
                                                                ], ), 
                                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                                type = 'doc', 
                                                                content = [
                                                                    keplar_api.models.content_node.ContentNode()
                                                                    ], ), 
                                                            version = 1.337, 
                                                            created_at = '', 
                                                            updated_at = '', ), 
                                                        brief_document = '', 
                                                        screener_questions = [
                                                            keplar_api.models.screener_question.ScreenerQuestion()
                                                            ], 
                                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                            sample_size = 1.337, 
                                                            invite_title = '', 
                                                            invite_description = '', 
                                                            participants = [
                                                                keplar_api.models.participant_create.ParticipantCreate(
                                                                    id = '', 
                                                                    name = '', 
                                                                    email = '', 
                                                                    phone_number = '01234', )
                                                                ], 
                                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                respondent_attributes = [
                                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                        qualifications = [
                                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                                allowed_option_ids = [
                                                                                    null
                                                                                    ], 
                                                                                question_id = 1.337, )
                                                                            ], 
                                                                        quota = 1.337, 
                                                                        quota_name = '', )
                                                                    ], 
                                                                country_code = '', 
                                                                language_code = '', 
                                                                length_of_interview = 1.337, 
                                                                incidence_rate = 1.337, 
                                                                compensation = 1.337, ), 
                                                            use_public_link = True, ), ), 
                                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        language = 'en', ), 
                                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                            markdown_report = '', 
                                                            structured_report = null, 
                                                            call_ids = [
                                                                ''
                                                                ], 
                                                            references = {
                                                                'key' : ''
                                                                }, ), ), 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    kind = '', 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            kind = 'text', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                keplar_api.models.thread.Thread(
                                                                                    id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_by_id = '', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    notebook_id = '', 
                                                                                    notebook = keplar_api.models.notebook.Notebook(
                                                                                        id = '', 
                                                                                        workspace_id = '', 
                                                                                        created_by_id = '', 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                            sources = [
                                                                                                ''
                                                                                                ], 
                                                                                            mode = 'report', 
                                                                                            settings = keplar_api.models.settings.settings(), ), 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        notebook_artifact_version_groups = [
                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                id = '', 
                                                                                                notebook_id = '', 
                                                                                                artifact_version_group_id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                artifact_version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                    id = '', 
                                                                                                    project_id = '', 
                                                                                                    kind = 'thematic_analysis', 
                                                                                                    latest_artifact_id = '', 
                                                                                                    latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                        id = '', 
                                                                                                        title = '', 
                                                                                                        kind = 'thematic_analysis', 
                                                                                                        project_id = '', 
                                                                                                        attribute_kind_group_id = '', 
                                                                                                        version_group_id = '', 
                                                                                                        metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                            status = 'draft', 
                                                                                                            status_message = '', 
                                                                                                            progress = 1.337, 
                                                                                                            description = '', ), 
                                                                                                        created_by_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                            id = '', 
                                                                                                            name = '', 
                                                                                                            description = '', 
                                                                                                            scope = 'org', 
                                                                                                            purpose = 'screener_response', 
                                                                                                            workspace_id = '', 
                                                                                                            project_id = '', 
                                                                                                            created_by_id = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            attribute_kinds = [
                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                    id = '', 
                                                                                                                    key = '', 
                                                                                                                    label = '', 
                                                                                                                    value_kind = 'single', 
                                                                                                                    description = '', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                    attributes = [
                                                                                                                        keplar_api.models.attribute.Attribute(
                                                                                                                            id = '', 
                                                                                                                            attribute_kind_id = '', 
                                                                                                                            value = '', 
                                                                                                                            description = '', 
                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                id = '', 
                                                                                                                                key = '', 
                                                                                                                                label = '', 
                                                                                                                                value_kind = 'single', 
                                                                                                                                description = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute_kind_group_id = '', ), 
                                                                                                                            participant_attributes = [
                                                                                                                                keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                    participant_id = '', 
                                                                                                                                    attribute_id = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    participant = keplar_api.models.participant.Participant(
                                                                                                                                        id = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        email = '', 
                                                                                                                                        phone_number = '', 
                                                                                                                                        name = '', 
                                                                                                                                        workspace_id = '', 
                                                                                                                                        participant_invites = [
                                                                                                                                            keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                                                                code = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_id = '', 
                                                                                                                                                invite_id = '', 
                                                                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                                                                    id = '', 
                                                                                                                                                    name = '', 
                                                                                                                                                    description = '', 
                                                                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                                                                    code = '', 
                                                                                                                                                    status = 'PREVIEW', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    calls = [
                                                                                                                                                        keplar_api.models.call.Call(
                                                                                                                                                            id = '', 
                                                                                                                                                            vendor = '', 
                                                                                                                                                            vendor_call_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            duration_ms = 1.337, 
                                                                                                                                                            phone_number = '', 
                                                                                                                                                            invite_response_id = '', 
                                                                                                                                                            participant_id = '', 
                                                                                                                                                            invite_id = '', 
                                                                                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                                                                                id = '', 
                                                                                                                                                                kind = 'VOICE_CALL', 
                                                                                                                                                                status = 'PENDING', 
                                                                                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                invite_id = '', 
                                                                                                                                                                vendor_participant_id = '', 
                                                                                                                                                                participant_id = '', 
                                                                                                                                                                invite_response_attributes = [
                                                                                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                                                        invite_response_id = '', 
                                                                                                                                                                        attribute_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            attribute_kind_id = '', 
                                                                                                                                                                            value = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                    ], ), 
                                                                                                                                                            events = [
                                                                                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                                                                                    call_id = '', 
                                                                                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    kind = '', 
                                                                                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                                                                                    call = keplar_api.models.call.Call(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        vendor = '', 
                                                                                                                                                                        vendor_call_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        duration_ms = 1.337, 
                                                                                                                                                                        phone_number = '', 
                                                                                                                                                                        invite_response_id = '', 
                                                                                                                                                                        participant_id = '', 
                                                                                                                                                                        invite_id = '', 
                                                                                                                                                                        conversation_messages = [
                                                                                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                                                                                call_id = '', 
                                                                                                                                                                                index = 1.337, 
                                                                                                                                                                                role = '', 
                                                                                                                                                                                source = '', 
                                                                                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                message = '', 
                                                                                                                                                                                duration = 1.337, 
                                                                                                                                                                                seconds_from_start = 1.337, 
                                                                                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                                                                                    call_id = '', 
                                                                                                                                                                                    index = 1.337, 
                                                                                                                                                                                    description = '', ), )
                                                                                                                                                                            ], 
                                                                                                                                                                        conversation_message_topics = [
                                                                                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                                                                                call_id = '', 
                                                                                                                                                                                index = 1.337, 
                                                                                                                                                                                description = '', )
                                                                                                                                                                            ], ), )
                                                                                                                                                                ], 
                                                                                                                                                            conversation_messages = [
                                                                                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                                                                    call_id = '', 
                                                                                                                                                                    index = 1.337, 
                                                                                                                                                                    role = '', 
                                                                                                                                                                    source = '', 
                                                                                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    message = '', 
                                                                                                                                                                    duration = 1.337, 
                                                                                                                                                                    seconds_from_start = 1.337, 
                                                                                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                                                                                ], 
                                                                                                                                                            conversation_message_topics = [
                                                                                                                                                                
                                                                                                                                                                ], )
                                                                                                                                                        ], 
                                                                                                                                                    invite_responses = [
                                                                                                                                                        keplar_api.models.invite_response.InviteResponse(
                                                                                                                                                            id = '', 
                                                                                                                                                            kind = 'VOICE_CALL', 
                                                                                                                                                            status = 'PENDING', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            invite_id = '', 
                                                                                                                                                            vendor_participant_id = '', 
                                                                                                                                                            participant_id = '', )
                                                                                                                                                        ], ), )
                                                                                                                                            ], 
                                                                                                                                        invite_responses = [
                                                                                                                                            
                                                                                                                                            ], 
                                                                                                                                        calls = [
                                                                                                                                            
                                                                                                                                            ], ), 
                                                                                                                                    attribute = , )
                                                                                                                                ], 
                                                                                                                            invite_response_attributes = [
                                                                                                                                keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                    invite_response_id = '', 
                                                                                                                                    attribute_id = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                ], )
                                                                                                                        ], )
                                                                                                                ], 
                                                                                                            artifacts = [
                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                    id = '', 
                                                                                                                    title = '', 
                                                                                                                    kind = , 
                                                                                                                    project_id = '', 
                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                    version_group_id = '', 
                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                        status = 'draft', 
                                                                                                                        status_message = '', 
                                                                                                                        progress = 1.337, 
                                                                                                                        description = '', ), 
                                                                                                                    created_by_id = '', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                        id = '', 
                                                                                                                        project_id = '', 
                                                                                                                        kind = , 
                                                                                                                        latest_artifact_id = '', ), 
                                                                                                                    latest_for_group = , )
                                                                                                                ], ), 
                                                                                                        version_group = , 
                                                                                                        latest_for_group = , ), 
                                                                                                    artifacts = [
                                                                                                        
                                                                                                        ], ), )
                                                                                            ], ), 
                                                                                    thread_files = [
                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            thread_id = '', 
                                                                                            file_id = '', 
                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_by_id = '', 
                                                                                                workspace_id = '', 
                                                                                                project_id = '', 
                                                                                                notebook_id = '', ), 
                                                                                            file = keplar_api.models.file.File(
                                                                                                id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                filename = '', 
                                                                                                display_name = '', 
                                                                                                mime_type = 'image/jpeg', 
                                                                                                size = '', 
                                                                                                bucket_name = '', 
                                                                                                gcs_path = '', 
                                                                                                gcs_generation = '', 
                                                                                                uploaded_by_id = '', 
                                                                                                workspace_id = '', 
                                                                                                description = '', 
                                                                                                is_public = True, 
                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                public_url = '', 
                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                        ], )
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = , 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = [
                                                            
                                                            ], 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    moderator = , 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    project_files = [
                                                        keplar_api.models.project_file.ProjectFile(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            project_id = '', 
                                                            file_id = '', 
                                                            description = '', )
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifacts = , 
                                                    artifact_version_group = [
                                                        
                                                        ], )
                                                ], 
                                            participants = [
                                                keplar_api.models.participant.Participant(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    email = '', 
                                                    phone_number = '', 
                                                    name = '', 
                                                    workspace_id = '', )
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', )
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        workspace_members = , 
                                        projects = [
                                            
                                            ], 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            workspace_members = , 
                            projects = , 
                            chat_sessions = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        project = , 
                        calls = , 
                        participant_invites = [
                            keplar_api.models.participant_invite.ParticipantInvite(
                                code = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                participant_id = '', 
                                invite_id = '', )
                            ], 
                        invite_responses = , )
                    ],
                chat_sessions = [
                    keplar_api.models.chat_session.ChatSession(
                        id = '', 
                        name = '', 
                        description = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        kind = '', 
                        data = null, 
                        created_by_id = '', 
                        project_id = '', 
                        created_by = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            projects = [
                                                keplar_api.models.project.Project(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    name = '', 
                                                    description = '', 
                                                    status = 'ACTIVE', 
                                                    created_by_id = '', 
                                                    workspace_id = '', 
                                                    moderator_id = '', 
                                                    config = keplar_api.models.project_config.ProjectConfig(
                                                        project_kind = 'custom', 
                                                        prompt_variables = {
                                                            'key' : null
                                                            }, 
                                                        learning_plan = '', 
                                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                                            title = '', 
                                                            objective = '', 
                                                            learning_goals = '', 
                                                            key_questions = '', 
                                                            conversation_flow = [
                                                                ''
                                                                ], 
                                                            rules = [
                                                                ''
                                                                ], 
                                                            assets = [
                                                                ''
                                                                ], ), 
                                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                                type = 'doc', 
                                                                content = [
                                                                    keplar_api.models.content_node.ContentNode()
                                                                    ], ), 
                                                            version = 1.337, 
                                                            created_at = '', 
                                                            updated_at = '', ), 
                                                        brief_document = '', 
                                                        screener_questions = [
                                                            keplar_api.models.screener_question.ScreenerQuestion()
                                                            ], 
                                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                            sample_size = 1.337, 
                                                            invite_title = '', 
                                                            invite_description = '', 
                                                            participants = [
                                                                keplar_api.models.participant_create.ParticipantCreate(
                                                                    id = '', 
                                                                    name = '', 
                                                                    email = '', 
                                                                    phone_number = '01234', )
                                                                ], 
                                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                respondent_attributes = [
                                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                        qualifications = [
                                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                                allowed_option_ids = [
                                                                                    null
                                                                                    ], 
                                                                                question_id = 1.337, )
                                                                            ], 
                                                                        quota = 1.337, 
                                                                        quota_name = '', )
                                                                    ], 
                                                                country_code = '', 
                                                                language_code = '', 
                                                                length_of_interview = 1.337, 
                                                                incidence_rate = 1.337, 
                                                                compensation = 1.337, ), 
                                                            use_public_link = True, ), ), 
                                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        language = 'en', ), 
                                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                            markdown_report = '', 
                                                            structured_report = null, 
                                                            call_ids = [
                                                                ''
                                                                ], 
                                                            references = {
                                                                'key' : ''
                                                                }, ), ), 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    moderator = , 
                                                    invites = [
                                                        
                                                        ], 
                                                    project_files = [
                                                        keplar_api.models.project_file.ProjectFile(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            project_id = '', 
                                                            file_id = '', 
                                                            description = '', )
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifacts = , 
                                                    artifact_version_group = [
                                                        
                                                        ], )
                                                ], 
                                            participants = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', )
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        workspace_members = , 
                                        projects = [
                                            
                                            ], 
                                        invites = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            workspace_members = , 
                            projects = , 
                            invites = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        project = , 
                        chat_messages = [
                            keplar_api.models.chat_message.ChatMessage(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                content = '', 
                                role = 'user', 
                                chat_session_id = '', 
                                chat_session = keplar_api.models.chat_session.ChatSession(
                                    id = '', 
                                    name = '', 
                                    description = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    created_by_id = '', 
                                    project_id = '', ), )
                            ], )
                    ],
                moderators = [
                    keplar_api.models.moderator.Moderator(
                        id = '', 
                        name = '', 
                        description = '', 
                        visibility = 'public', 
                        config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                            system_prompt = '', 
                            model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                provider = 'openai', 
                                model = 'gpt-4.1', ), 
                            first_message = '', 
                            end_call_message = '', 
                            max_duration_seconds = 1.337, 
                            voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                provider = 'vapi', 
                                voice_id = 'Elliot', ), 
                            tools = [
                                keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                    type = 'function', 
                                    function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                        name = '', 
                                        description = '', 
                                        parameters = {
                                            'key' : null
                                            }, ), )
                                ], 
                            language = 'en', ), 
                        vendor = 'vapi', 
                        vendor_id = '', 
                        vendor_data = null, 
                        workspace_id = '', 
                        created_by_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        parent_moderator_id = '', 
                        workspace = keplar_api.models.workspace.Workspace(
                            id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            projects = [
                                keplar_api.models.project.Project(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    description = '', 
                                    status = 'ACTIVE', 
                                    created_by_id = '', 
                                    workspace_id = '', 
                                    moderator_id = '', 
                                    config = keplar_api.models.project_config.ProjectConfig(
                                        project_kind = 'custom', 
                                        prompt_variables = {
                                            'key' : null
                                            }, 
                                        learning_plan = '', 
                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                            title = '', 
                                            objective = '', 
                                            learning_goals = '', 
                                            key_questions = '', 
                                            conversation_flow = [
                                                ''
                                                ], 
                                            rules = [
                                                ''
                                                ], 
                                            assets = [
                                                ''
                                                ], ), 
                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                type = 'doc', 
                                                content = [
                                                    keplar_api.models.content_node.ContentNode()
                                                    ], ), 
                                            version = 1.337, 
                                            created_at = '', 
                                            updated_at = '', ), 
                                        brief_document = '', 
                                        screener_questions = [
                                            keplar_api.models.screener_question.ScreenerQuestion()
                                            ], 
                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                            sample_size = 1.337, 
                                            invite_title = '', 
                                            invite_description = '', 
                                            participants = [
                                                keplar_api.models.participant_create.ParticipantCreate(
                                                    id = '', 
                                                    name = '', 
                                                    email = '', 
                                                    phone_number = '01234', 
                                                    data = keplar_api.models.data.data(), )
                                                ], 
                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                respondent_attributes = [
                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                        qualifications = [
                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                allowed_option_ids = [
                                                                    null
                                                                    ], 
                                                                question_id = 1.337, )
                                                            ], 
                                                        quota = 1.337, 
                                                        quota_name = '', )
                                                    ], 
                                                country_code = '', 
                                                language_code = '', 
                                                length_of_interview = 1.337, 
                                                incidence_rate = 1.337, 
                                                compensation = 1.337, ), 
                                            use_public_link = True, ), ), 
                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                        first_message = '', 
                                        end_call_message = '', 
                                        max_duration_seconds = 1.337, 
                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                            provider = 'vapi', 
                                            voice_id = 'Elliot', ), ), 
                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                            markdown_report = '', 
                                            structured_report = null, 
                                            call_ids = [
                                                ''
                                                ], 
                                            references = {
                                                'key' : ''
                                                }, ), ), 
                                    created_by = keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        data = keplar_api.models.user_data.UserData(
                                            launch_trial = True, 
                                            admin_level = 'ADMIN', 
                                            is_dummy = True, ), 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_kind = 'email_verification', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        org = keplar_api.models.org.Org(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            domain = '', 
                                            default_workspace_id = '', 
                                            users = [
                                                keplar_api.models.user.User(
                                                    id = '', 
                                                    seq = 1.337, 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    provider = 'google', 
                                                    user_id = '', 
                                                    email = '', 
                                                    name = '', 
                                                    account_status = 'ACTIVE', 
                                                    location = '', 
                                                    profile_image_url = '', 
                                                    password_hash = '', 
                                                    email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    token = '', 
                                                    token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    org_id = '', 
                                                    default_workspace_id = '', 
                                                    default_workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = keplar_api.models.moderator.Moderator(
                                                                                id = '', 
                                                                                name = '', 
                                                                                description = '', 
                                                                                visibility = 'public', 
                                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                                    system_prompt = '', 
                                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                        provider = 'openai', 
                                                                                        model = 'gpt-4.1', ), 
                                                                                    first_message = '', 
                                                                                    end_call_message = '', 
                                                                                    max_duration_seconds = 1.337, 
                                                                                    voice = , ), 
                                                                                vendor = 'vapi', 
                                                                                vendor_id = '', 
                                                                                vendor_data = null, 
                                                                                workspace_id = '', 
                                                                                created_by_id = '', 
                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                parent_moderator_id = '', 
                                                                                parent_moderator = , 
                                                                                child_moderators = [
                                                                                    
                                                                                    ], ), 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    workspace_members = [
                                                        keplar_api.models.workspace_member.WorkspaceMember(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            role = 'owner', 
                                                            user_id = '', 
                                                            workspace_id = '', )
                                                        ], 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    uploaded_files = [
                                                        
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifact = [
                                                        
                                                        ], 
                                                    notebooks = [
                                                        
                                                        ], )
                                                ], 
                                            default_workspace = , ), 
                                        default_workspace = , 
                                        workspace_members = , 
                                        invites = , 
                                        chat_sessions = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , ), 
                                    moderator = , 
                                    invites = , 
                                    chat_sessions = , 
                                    project_files = [
                                        keplar_api.models.project_file.ProjectFile(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            project_id = '', 
                                            file_id = '', 
                                            description = '', )
                                        ], 
                                    threads = , 
                                    attribute_kind_group = , 
                                    artifacts = , 
                                    artifact_version_group = [
                                        
                                        ], )
                                ], 
                            participants = [
                                
                                ], 
                            files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_groups = [
                                
                                ], 
                            workspace_members = , 
                            notebooks = , 
                            default_for_users = [
                                
                                ], 
                            default_for_orgs = [
                                
                                ], ), 
                        created_by = , 
                        parent_moderator = , 
                        child_moderators = [
                            
                            ], 
                        projects = [
                            
                            ], )
                    ],
                uploaded_files = [
                    keplar_api.models.file.File(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        filename = '', 
                        display_name = '', 
                        mime_type = 'image/jpeg', 
                        size = '', 
                        bucket_name = '', 
                        gcs_path = '', 
                        gcs_generation = '', 
                        uploaded_by_id = '', 
                        workspace_id = '', 
                        description = '', 
                        metadata = {
                            'key' : null
                            }, 
                        is_public = True, 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        public_url = '', 
                        public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        uploaded_by = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            projects = [
                                                keplar_api.models.project.Project(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    name = '', 
                                                    description = '', 
                                                    status = 'ACTIVE', 
                                                    created_by_id = '', 
                                                    workspace_id = '', 
                                                    moderator_id = '', 
                                                    config = keplar_api.models.project_config.ProjectConfig(
                                                        project_kind = 'custom', 
                                                        prompt_variables = {
                                                            'key' : null
                                                            }, 
                                                        learning_plan = '', 
                                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                                            title = '', 
                                                            objective = '', 
                                                            learning_goals = '', 
                                                            key_questions = '', 
                                                            conversation_flow = [
                                                                ''
                                                                ], 
                                                            rules = [
                                                                ''
                                                                ], 
                                                            assets = [
                                                                ''
                                                                ], ), 
                                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                                type = 'doc', 
                                                                content = [
                                                                    keplar_api.models.content_node.ContentNode()
                                                                    ], ), 
                                                            version = 1.337, 
                                                            created_at = '', 
                                                            updated_at = '', ), 
                                                        brief_document = '', 
                                                        screener_questions = [
                                                            keplar_api.models.screener_question.ScreenerQuestion()
                                                            ], 
                                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                            sample_size = 1.337, 
                                                            invite_title = '', 
                                                            invite_description = '', 
                                                            participants = [
                                                                keplar_api.models.participant_create.ParticipantCreate(
                                                                    id = '', 
                                                                    name = '', 
                                                                    email = '', 
                                                                    phone_number = '01234', )
                                                                ], 
                                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                respondent_attributes = [
                                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                        qualifications = [
                                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                                allowed_option_ids = [
                                                                                    null
                                                                                    ], 
                                                                                question_id = 1.337, )
                                                                            ], 
                                                                        quota = 1.337, 
                                                                        quota_name = '', )
                                                                    ], 
                                                                country_code = '', 
                                                                language_code = '', 
                                                                length_of_interview = 1.337, 
                                                                incidence_rate = 1.337, 
                                                                compensation = 1.337, ), 
                                                            use_public_link = True, ), ), 
                                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        language = 'en', ), 
                                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                            markdown_report = '', 
                                                            structured_report = null, 
                                                            call_ids = [
                                                                ''
                                                                ], 
                                                            references = {
                                                                'key' : ''
                                                                }, ), ), 
                                                    created_by = , 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = , )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    moderator = , 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    project_files = [
                                                        keplar_api.models.project_file.ProjectFile(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            project_id = '', 
                                                            file_id = '', 
                                                            description = '', )
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifacts = , 
                                                    artifact_version_group = [
                                                        
                                                        ], )
                                                ], 
                                            participants = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', )
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        workspace_members = , 
                                        projects = [
                                            
                                            ], 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            workspace_members = , 
                            projects = , 
                            invites = , 
                            chat_sessions = , 
                            moderators = , 
                            threads = , 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        workspace = , 
                        project_files = , 
                        thread_files = , )
                    ],
                threads = [
                    keplar_api.models.thread.Thread(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        kind = 'CREATE_PROJECT', 
                        description = '', 
                        metadata = keplar_api.models.thread_metadata.ThreadMetadata(
                            status = 'draft', 
                            project_brief_drafts = [
                                keplar_api.models.project_brief.ProjectBrief(
                                    title = '', 
                                    objective = '', 
                                    learning_goals = '', 
                                    key_questions = '', 
                                    conversation_flow = [
                                        ''
                                        ], 
                                    rules = [
                                        ''
                                        ], 
                                    assets = [
                                        ''
                                        ], )
                                ], 
                            project_brief_document_versions = [
                                keplar_api.models.brief_document_version.BriefDocumentVersion(
                                    doc = keplar_api.models.brief_document.BriefDocument(
                                        type = 'doc', 
                                        content = [
                                            keplar_api.models.content_node.ContentNode()
                                            ], ), 
                                    version = 1.337, 
                                    created_at = '', 
                                    updated_at = '', )
                                ], ), 
                        created_by_id = '', 
                        workspace_id = '', 
                        project_id = '', 
                        notebook_id = '', 
                        created_by = keplar_api.models.user.User(
                            id = '', 
                            seq = 1.337, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            provider = 'google', 
                            user_id = '', 
                            email = '', 
                            name = '', 
                            account_status = 'ACTIVE', 
                            location = '', 
                            profile_image_url = '', 
                            data = keplar_api.models.user_data.UserData(
                                launch_trial = True, 
                                admin_level = 'ADMIN', 
                                is_dummy = True, ), 
                            password_hash = '', 
                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            token = '', 
                            token_kind = 'email_verification', 
                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            org_id = '', 
                            default_workspace_id = '', 
                            org = keplar_api.models.org.Org(
                                id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                domain = '', 
                                default_workspace_id = '', 
                                users = [
                                    keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        default_workspace = keplar_api.models.workspace.Workspace(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            projects = [
                                                keplar_api.models.project.Project(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    name = '', 
                                                    description = '', 
                                                    status = 'ACTIVE', 
                                                    created_by_id = '', 
                                                    workspace_id = '', 
                                                    moderator_id = '', 
                                                    config = keplar_api.models.project_config.ProjectConfig(
                                                        project_kind = 'custom', 
                                                        prompt_variables = {
                                                            'key' : null
                                                            }, 
                                                        learning_plan = '', 
                                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                                            title = '', 
                                                            objective = '', 
                                                            learning_goals = '', 
                                                            key_questions = '', 
                                                            conversation_flow = [
                                                                ''
                                                                ], ), 
                                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                                type = 'doc', 
                                                                content = [
                                                                    keplar_api.models.content_node.ContentNode()
                                                                    ], ), 
                                                            version = 1.337, 
                                                            created_at = '', 
                                                            updated_at = '', ), 
                                                        brief_document = '', 
                                                        screener_questions = [
                                                            keplar_api.models.screener_question.ScreenerQuestion()
                                                            ], 
                                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                            sample_size = 1.337, 
                                                            invite_title = '', 
                                                            invite_description = '', 
                                                            participants = [
                                                                keplar_api.models.participant_create.ParticipantCreate(
                                                                    id = '', 
                                                                    name = '', 
                                                                    email = '', 
                                                                    phone_number = '01234', )
                                                                ], 
                                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                respondent_attributes = [
                                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                        qualifications = [
                                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                                allowed_option_ids = [
                                                                                    null
                                                                                    ], 
                                                                                question_id = 1.337, )
                                                                            ], 
                                                                        quota = 1.337, 
                                                                        quota_name = '', )
                                                                    ], 
                                                                country_code = '', 
                                                                language_code = '', 
                                                                length_of_interview = 1.337, 
                                                                incidence_rate = 1.337, 
                                                                compensation = 1.337, ), 
                                                            use_public_link = True, ), ), 
                                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                        first_message = '', 
                                                        end_call_message = '', 
                                                        max_duration_seconds = 1.337, 
                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                            provider = 'vapi', 
                                                            voice_id = 'Elliot', ), 
                                                        language = 'en', ), 
                                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                                            markdown_report = '', 
                                                            structured_report = null, 
                                                            call_ids = [
                                                                ''
                                                                ], 
                                                            references = {
                                                                'key' : ''
                                                                }, ), ), 
                                                    workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = keplar_api.models.file.File(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            filename = '', 
                                                                            display_name = '', 
                                                                            mime_type = 'image/jpeg', 
                                                                            size = '', 
                                                                            bucket_name = '', 
                                                                            gcs_path = '', 
                                                                            gcs_generation = '', 
                                                                            uploaded_by_id = '', 
                                                                            workspace_id = '', 
                                                                            description = '', 
                                                                            is_public = True, 
                                                                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            public_url = '', 
                                                                            public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            thread_files = [
                                                                                keplar_api.models.thread_file.ThreadFile(
                                                                                    id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    thread_id = '', 
                                                                                    file_id = '', 
                                                                                    thread = keplar_api.models.thread.Thread(
                                                                                        id = '', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        created_by_id = '', 
                                                                                        workspace_id = '', 
                                                                                        project_id = '', 
                                                                                        notebook_id = '', ), )
                                                                                ], ), )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    moderator = , 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    project_files = [
                                                        keplar_api.models.project_file.ProjectFile(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            project_id = '', 
                                                            file_id = '', 
                                                            description = '', )
                                                        ], 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifacts = , 
                                                    artifact_version_group = [
                                                        
                                                        ], )
                                                ], 
                                            participants = [
                                                
                                                ], 
                                            moderators = [
                                                
                                                ], 
                                            files = [
                                                
                                                ], 
                                            attribute_kind_groups = [
                                                
                                                ], 
                                            workspace_members = [
                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                    id = '', 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    role = 'owner', 
                                                    user_id = '', 
                                                    workspace_id = '', )
                                                ], 
                                            notebooks = [
                                                
                                                ], 
                                            default_for_users = [
                                                
                                                ], 
                                            default_for_orgs = [
                                                
                                                ], ), 
                                        workspace_members = , 
                                        projects = [
                                            
                                            ], 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , )
                                    ], 
                                default_workspace = , ), 
                            default_workspace = , 
                            workspace_members = , 
                            projects = , 
                            invites = , 
                            chat_sessions = , 
                            moderators = , 
                            uploaded_files = [
                                
                                ], 
                            attribute_kind_group = , 
                            artifact = [
                                
                                ], 
                            notebooks = , ), 
                        workspace = , 
                        project = , 
                        notebook = , 
                        thread_files = , )
                    ],
                attribute_kind_group = [
                    keplar_api.models.attribute_kind_group.AttributeKindGroup(
                        id = '', 
                        name = '', 
                        description = '', 
                        scope = 'org', 
                        purpose = 'screener_response', 
                        workspace_id = '', 
                        project_id = '', 
                        created_by_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        workspace = keplar_api.models.workspace.Workspace(
                            id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            projects = [
                                keplar_api.models.project.Project(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    description = '', 
                                    status = 'ACTIVE', 
                                    created_by_id = '', 
                                    workspace_id = '', 
                                    moderator_id = '', 
                                    config = keplar_api.models.project_config.ProjectConfig(
                                        project_kind = 'custom', 
                                        prompt_variables = {
                                            'key' : null
                                            }, 
                                        learning_plan = '', 
                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                            title = '', 
                                            objective = '', 
                                            learning_goals = '', 
                                            key_questions = '', 
                                            conversation_flow = [
                                                ''
                                                ], 
                                            rules = [
                                                ''
                                                ], 
                                            assets = [
                                                ''
                                                ], ), 
                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                type = 'doc', 
                                                content = [
                                                    keplar_api.models.content_node.ContentNode()
                                                    ], ), 
                                            version = 1.337, 
                                            created_at = '', 
                                            updated_at = '', ), 
                                        brief_document = '', 
                                        screener_questions = [
                                            keplar_api.models.screener_question.ScreenerQuestion()
                                            ], 
                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                            sample_size = 1.337, 
                                            invite_title = '', 
                                            invite_description = '', 
                                            participants = [
                                                keplar_api.models.participant_create.ParticipantCreate(
                                                    id = '', 
                                                    name = '', 
                                                    email = '', 
                                                    phone_number = '01234', 
                                                    data = keplar_api.models.data.data(), )
                                                ], 
                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                respondent_attributes = [
                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                        qualifications = [
                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                allowed_option_ids = [
                                                                    null
                                                                    ], 
                                                                question_id = 1.337, )
                                                            ], 
                                                        quota = 1.337, 
                                                        quota_name = '', )
                                                    ], 
                                                country_code = '', 
                                                language_code = '', 
                                                length_of_interview = 1.337, 
                                                incidence_rate = 1.337, 
                                                compensation = 1.337, ), 
                                            use_public_link = True, ), ), 
                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                        first_message = '', 
                                        end_call_message = '', 
                                        max_duration_seconds = 1.337, 
                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                            provider = 'vapi', 
                                            voice_id = 'Elliot', ), 
                                        language = 'en', ), 
                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                            markdown_report = '', 
                                            structured_report = null, 
                                            call_ids = [
                                                ''
                                                ], 
                                            references = {
                                                'key' : ''
                                                }, ), ), 
                                    created_by = keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        data = keplar_api.models.user_data.UserData(
                                            launch_trial = True, 
                                            admin_level = 'ADMIN', 
                                            is_dummy = True, ), 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_kind = 'email_verification', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        org = keplar_api.models.org.Org(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            domain = '', 
                                            default_workspace_id = '', 
                                            users = [
                                                keplar_api.models.user.User(
                                                    id = '', 
                                                    seq = 1.337, 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    provider = 'google', 
                                                    user_id = '', 
                                                    email = '', 
                                                    name = '', 
                                                    account_status = 'ACTIVE', 
                                                    location = '', 
                                                    profile_image_url = '', 
                                                    password_hash = '', 
                                                    email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    token = '', 
                                                    token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    org_id = '', 
                                                    default_workspace_id = '', 
                                                    default_workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        notebooks = [
                                                            keplar_api.models.notebook.Notebook(
                                                                id = '', 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                    sources = [
                                                                        ''
                                                                        ], 
                                                                    mode = 'report', 
                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    workspace_members = [
                                                        keplar_api.models.workspace_member.WorkspaceMember(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            role = 'owner', 
                                                            user_id = '', 
                                                            workspace_id = '', )
                                                        ], 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    moderators = [
                                                        
                                                        ], 
                                                    uploaded_files = [
                                                        
                                                        ], 
                                                    threads = , 
                                                    artifact = [
                                                        
                                                        ], 
                                                    notebooks = [
                                                        
                                                        ], )
                                                ], 
                                            default_workspace = , ), 
                                        default_workspace = , 
                                        workspace_members = , 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , ), 
                                    moderator = , 
                                    invites = , 
                                    chat_sessions = , 
                                    project_files = [
                                        keplar_api.models.project_file.ProjectFile(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            project_id = '', 
                                            file_id = '', 
                                            description = '', )
                                        ], 
                                    threads = , 
                                    artifacts = , 
                                    artifact_version_group = [
                                        
                                        ], )
                                ], 
                            participants = [
                                
                                ], 
                            moderators = , 
                            files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_groups = [
                                
                                ], 
                            workspace_members = , 
                            notebooks = , 
                            default_for_users = [
                                
                                ], 
                            default_for_orgs = [
                                
                                ], ), 
                        project = , 
                        created_by = , 
                        attribute_kinds = [
                            
                            ], 
                        artifacts = , )
                    ],
                artifact = [
                    keplar_api.models.artifact.Artifact(
                        id = '', 
                        title = '', 
                        kind = 'thematic_analysis', 
                        project_id = '', 
                        attribute_kind_group_id = '', 
                        version_group_id = '', 
                        data = null, 
                        metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                            status = 'draft', 
                            status_message = '', 
                            progress = 1.337, 
                            description = '', ), 
                        created_by_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = keplar_api.models.project.Project(
                            id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            description = '', 
                            status = 'ACTIVE', 
                            created_by_id = '', 
                            workspace_id = '', 
                            moderator_id = '', 
                            config = keplar_api.models.project_config.ProjectConfig(
                                project_kind = 'custom', 
                                prompt_variables = {
                                    'key' : null
                                    }, 
                                learning_plan = '', 
                                brief = keplar_api.models.project_brief.ProjectBrief(
                                    title = '', 
                                    objective = '', 
                                    learning_goals = '', 
                                    key_questions = '', 
                                    conversation_flow = [
                                        ''
                                        ], 
                                    rules = [
                                        ''
                                        ], 
                                    assets = [
                                        ''
                                        ], ), 
                                current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                    doc = keplar_api.models.brief_document.BriefDocument(
                                        type = 'doc', 
                                        content = [
                                            keplar_api.models.content_node.ContentNode()
                                            ], ), 
                                    version = 1.337, 
                                    created_at = '', 
                                    updated_at = '', ), 
                                brief_document = '', 
                                screener_questions = [
                                    keplar_api.models.screener_question.ScreenerQuestion()
                                    ], 
                                audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                    sample_size = 1.337, 
                                    invite_title = '', 
                                    invite_description = '', 
                                    participants = [
                                        keplar_api.models.participant_create.ParticipantCreate(
                                            id = '', 
                                            name = '', 
                                            email = '', 
                                            phone_number = '01234', )
                                        ], 
                                    panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                        respondent_attributes = [
                                            keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                qualifications = [
                                                    keplar_api.models.panel_qualification.PanelQualification(
                                                        allowed_option_ids = [
                                                            null
                                                            ], 
                                                        question_id = 1.337, )
                                                    ], 
                                                quota = 1.337, 
                                                quota_name = '', )
                                            ], 
                                        country_code = '', 
                                        language_code = '', 
                                        length_of_interview = 1.337, 
                                        incidence_rate = 1.337, 
                                        compensation = 1.337, ), 
                                    use_public_link = True, ), ), 
                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                first_message = '', 
                                end_call_message = '', 
                                max_duration_seconds = 1.337, 
                                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                    provider = 'vapi', 
                                    voice_id = 'Elliot', ), 
                                language = 'en', ), 
                            analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                    markdown_report = '', 
                                    structured_report = null, 
                                    call_ids = [
                                        ''
                                        ], 
                                    references = {
                                        'key' : ''
                                        }, ), ), 
                            created_by = keplar_api.models.user.User(
                                id = '', 
                                seq = 1.337, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                provider = 'google', 
                                user_id = '', 
                                email = '', 
                                name = '', 
                                account_status = 'ACTIVE', 
                                location = '', 
                                profile_image_url = '', 
                                password_hash = '', 
                                email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                token = '', 
                                token_kind = 'email_verification', 
                                token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                org_id = '', 
                                default_workspace_id = '', 
                                org = keplar_api.models.org.Org(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    domain = '', 
                                    default_workspace_id = '', 
                                    users = [
                                        keplar_api.models.user.User(
                                            id = '', 
                                            seq = 1.337, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            provider = 'google', 
                                            user_id = '', 
                                            email = '', 
                                            name = '', 
                                            account_status = 'ACTIVE', 
                                            location = '', 
                                            profile_image_url = '', 
                                            password_hash = '', 
                                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            token = '', 
                                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            org_id = '', 
                                            default_workspace_id = '', 
                                            default_workspace = keplar_api.models.workspace.Workspace(
                                                id = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                name = '', 
                                                projects = [
                                                    keplar_api.models.project.Project(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        description = '', 
                                                        status = 'ACTIVE', 
                                                        created_by_id = '', 
                                                        workspace_id = '', 
                                                        moderator_id = '', 
                                                        config = keplar_api.models.project_config.ProjectConfig(
                                                            prompt_variables = {
                                                                'key' : null
                                                                }, 
                                                            learning_plan = '', 
                                                            brief_document = '', ), 
                                                        conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                            first_message = '', 
                                                            end_call_message = '', 
                                                            max_duration_seconds = 1.337, 
                                                            voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                provider = 'vapi', 
                                                                voice_id = 'Elliot', ), ), 
                                                        workspace = keplar_api.models.workspace.Workspace(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            name = '', 
                                                            moderators = [
                                                                keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , 
                                                                        tools = [
                                                                            keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                                type = 'function', 
                                                                                function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    parameters = {
                                                                                        'key' : null
                                                                                        }, ), )
                                                                            ], ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    parent_moderator = keplar_api.models.moderator.Moderator(
                                                                        id = '', 
                                                                        name = '', 
                                                                        description = '', 
                                                                        visibility = 'public', 
                                                                        config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                            system_prompt = '', 
                                                                            model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                provider = 'openai', 
                                                                                model = 'gpt-4.1', ), 
                                                                            first_message = '', 
                                                                            end_call_message = '', 
                                                                            max_duration_seconds = 1.337, 
                                                                            voice = , ), 
                                                                        vendor = 'vapi', 
                                                                        vendor_id = '', 
                                                                        vendor_data = null, 
                                                                        workspace_id = '', 
                                                                        created_by_id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        parent_moderator_id = '', 
                                                                        child_moderators = [
                                                                            
                                                                            ], ), 
                                                                    child_moderators = [
                                                                        
                                                                        ], )
                                                                ], 
                                                            files = [
                                                                keplar_api.models.file.File(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    filename = '', 
                                                                    display_name = '', 
                                                                    mime_type = 'image/jpeg', 
                                                                    size = '', 
                                                                    bucket_name = '', 
                                                                    gcs_path = '', 
                                                                    gcs_generation = '', 
                                                                    uploaded_by_id = '', 
                                                                    workspace_id = '', 
                                                                    description = '', 
                                                                    is_public = True, 
                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    public_url = '', 
                                                                    public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    uploaded_by = , 
                                                                    project_files = [
                                                                        keplar_api.models.project_file.ProjectFile(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            project_id = '', 
                                                                            file_id = '', 
                                                                            description = '', 
                                                                            category = 'transcript', 
                                                                            file = keplar_api.models.file.File(
                                                                                id = '', 
                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                filename = '', 
                                                                                display_name = '', 
                                                                                mime_type = 'image/jpeg', 
                                                                                size = '', 
                                                                                bucket_name = '', 
                                                                                gcs_path = '', 
                                                                                gcs_generation = '', 
                                                                                uploaded_by_id = '', 
                                                                                workspace_id = '', 
                                                                                description = '', 
                                                                                is_public = True, 
                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                public_url = '', 
                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                thread_files = [
                                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                                        id = '', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        thread_id = '', 
                                                                                        file_id = '', 
                                                                                        thread = keplar_api.models.thread.Thread(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            name = '', 
                                                                                            description = '', 
                                                                                            created_by_id = '', 
                                                                                            workspace_id = '', 
                                                                                            project_id = '', 
                                                                                            notebook_id = '', 
                                                                                            notebook = keplar_api.models.notebook.Notebook(
                                                                                                id = '', 
                                                                                                workspace_id = '', 
                                                                                                created_by_id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                    sources = [
                                                                                                        ''
                                                                                                        ], 
                                                                                                    mode = 'report', 
                                                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                threads = [
                                                                                                    keplar_api.models.thread.Thread(
                                                                                                        id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        name = '', 
                                                                                                        description = '', 
                                                                                                        created_by_id = '', 
                                                                                                        workspace_id = '', 
                                                                                                        project_id = '', 
                                                                                                        notebook_id = '', )
                                                                                                    ], 
                                                                                                notebook_artifact_version_groups = [
                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                        id = '', 
                                                                                                        notebook_id = '', 
                                                                                                        artifact_version_group_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        artifact_version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                            id = '', 
                                                                                                            project_id = '', 
                                                                                                            kind = 'thematic_analysis', 
                                                                                                            latest_artifact_id = '', 
                                                                                                            latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                id = '', 
                                                                                                                title = '', 
                                                                                                                kind = , 
                                                                                                                project_id = '', 
                                                                                                                attribute_kind_group_id = '', 
                                                                                                                version_group_id = '', 
                                                                                                                metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                    status = 'draft', 
                                                                                                                    status_message = '', 
                                                                                                                    progress = 1.337, 
                                                                                                                    description = '', ), 
                                                                                                                created_by_id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                    id = '', 
                                                                                                                    name = '', 
                                                                                                                    description = '', 
                                                                                                                    scope = 'org', 
                                                                                                                    purpose = 'screener_response', 
                                                                                                                    workspace_id = '', 
                                                                                                                    project_id = '', 
                                                                                                                    created_by_id = '', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    attribute_kinds = [
                                                                                                                        keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                            id = '', 
                                                                                                                            key = '', 
                                                                                                                            label = '', 
                                                                                                                            value_kind = 'single', 
                                                                                                                            description = '', 
                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                            attributes = [
                                                                                                                                keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                                                id = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                email = '', 
                                                                                                                                                phone_number = '', 
                                                                                                                                                name = '', 
                                                                                                                                                workspace_id = '', 
                                                                                                                                                participant_invites = [
                                                                                                                                                    keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                                                                        code = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        invite_id = '', 
                                                                                                                                                        invite = keplar_api.models.invite.Invite(
                                                                                                                                                            id = '', 
                                                                                                                                                            name = '', 
                                                                                                                                                            description = '', 
                                                                                                                                                            config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                                                                            code = '', 
                                                                                                                                                            status = 'PREVIEW', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            calls = [
                                                                                                                                                                keplar_api.models.call.Call(
                                                                                                                                                                    id = '', 
                                                                                                                                                                    vendor = '', 
                                                                                                                                                                    vendor_call_id = '', 
                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    duration_ms = 1.337, 
                                                                                                                                                                    phone_number = '', 
                                                                                                                                                                    invite_response_id = '', 
                                                                                                                                                                    participant_id = '', 
                                                                                                                                                                    invite_id = '', 
                                                                                                                                                                    invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                                                                        status = 'PENDING', 
                                                                                                                                                                        evaluation = 'SYSTEM_PASS', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        invite_id = '', 
                                                                                                                                                                        vendor_participant_id = '', 
                                                                                                                                                                        participant_id = '', 
                                                                                                                                                                        invite_response_attributes = [
                                                                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                                                                invite_response_id = '', 
                                                                                                                                                                                attribute_id = '', 
                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                                                                    value = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                            ], ), 
                                                                                                                                                                    events = [
                                                                                                                                                                        keplar_api.models.call_event.CallEvent(
                                                                                                                                                                            call_id = '', 
                                                                                                                                                                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            kind = '', 
                                                                                                                                                                            data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                                                                                            call = keplar_api.models.call.Call(
                                                                                                                                                                                id = '', 
                                                                                                                                                                                vendor = '', 
                                                                                                                                                                                vendor_call_id = '', 
                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                duration_ms = 1.337, 
                                                                                                                                                                                phone_number = '', 
                                                                                                                                                                                invite_response_id = '', 
                                                                                                                                                                                participant_id = '', 
                                                                                                                                                                                invite_id = '', 
                                                                                                                                                                                conversation_messages = [
                                                                                                                                                                                    keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                                                                                        call_id = '', 
                                                                                                                                                                                        index = 1.337, 
                                                                                                                                                                                        role = '', 
                                                                                                                                                                                        source = '', 
                                                                                                                                                                                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                        end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                        message = '', 
                                                                                                                                                                                        duration = 1.337, 
                                                                                                                                                                                        seconds_from_start = 1.337, 
                                                                                                                                                                                        conversation_message_topic_index = 1.337, 
                                                                                                                                                                                        conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                                                                                            call_id = '', 
                                                                                                                                                                                            index = 1.337, 
                                                                                                                                                                                            description = '', ), )
                                                                                                                                                                                    ], 
                                                                                                                                                                                conversation_message_topics = [
                                                                                                                                                                                    keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                                                                                        call_id = '', 
                                                                                                                                                                                        index = 1.337, 
                                                                                                                                                                                        description = '', )
                                                                                                                                                                                    ], ), )
                                                                                                                                                                        ], 
                                                                                                                                                                    conversation_messages = [
                                                                                                                                                                        keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                                                                            call_id = '', 
                                                                                                                                                                            index = 1.337, 
                                                                                                                                                                            role = '', 
                                                                                                                                                                            source = '', 
                                                                                                                                                                            time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            message = '', 
                                                                                                                                                                            duration = 1.337, 
                                                                                                                                                                            seconds_from_start = 1.337, 
                                                                                                                                                                            conversation_message_topic_index = 1.337, )
                                                                                                                                                                        ], 
                                                                                                                                                                    conversation_message_topics = [
                                                                                                                                                                        
                                                                                                                                                                        ], )
                                                                                                                                                                ], 
                                                                                                                                                            invite_responses = [
                                                                                                                                                                keplar_api.models.invite_response.InviteResponse(
                                                                                                                                                                    id = '', 
                                                                                                                                                                    kind = 'VOICE_CALL', 
                                                                                                                                                                    status = 'PENDING', 
                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    invite_id = '', 
                                                                                                                                                                    vendor_participant_id = '', 
                                                                                                                                                                    participant_id = '', )
                                                                                                                                                                ], ), )
                                                                                                                                                    ], 
                                                                                                                                                invite_responses = [
                                                                                                                                                    
                                                                                                                                                    ], 
                                                                                                                                                calls = [
                                                                                                                                                    
                                                                                                                                                    ], ), 
                                                                                                                                            attribute = , )
                                                                                                                                        ], 
                                                                                                                                    invite_response_attributes = [
                                                                                                                                        keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                            invite_response_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], )
                                                                                                                                ], )
                                                                                                                        ], 
                                                                                                                    artifacts = [
                                                                                                                        
                                                                                                                        ], ), 
                                                                                                                version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                    id = '', 
                                                                                                                    project_id = '', 
                                                                                                                    kind = , 
                                                                                                                    latest_artifact_id = '', ), 
                                                                                                                latest_for_group = , ), 
                                                                                                            artifacts = [
                                                                                                                
                                                                                                                ], ), )
                                                                                                    ], ), ), )
                                                                                    ], ), )
                                                                        ], 
                                                                    thread_files = [
                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            thread_id = '', 
                                                                            file_id = '', )
                                                                        ], )
                                                                ], 
                                                            threads = [
                                                                
                                                                ], 
                                                            attribute_kind_groups = [
                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    scope = 'org', 
                                                                    purpose = 'screener_response', 
                                                                    workspace_id = '', 
                                                                    project_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                ], 
                                                            workspace_members = [
                                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    role = 'owner', 
                                                                    user_id = '', 
                                                                    workspace_id = '', 
                                                                    user = , )
                                                                ], 
                                                            notebooks = [
                                                                keplar_api.models.notebook.Notebook(
                                                                    id = '', 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    config = keplar_api.models.notebook_config.NotebookConfig(
                                                                        sources = [
                                                                            ''
                                                                            ], 
                                                                        mode = 'report', 
                                                                        settings = keplar_api.models.settings.settings(), ), 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                ], 
                                                            default_for_users = [
                                                                
                                                                ], 
                                                            default_for_orgs = [
                                                                keplar_api.models.org.Org(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    name = '', 
                                                                    domain = '', 
                                                                    default_workspace_id = '', )
                                                                ], ), 
                                                        moderator = , 
                                                        invites = [
                                                            keplar_api.models.invite.Invite(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                config = keplar_api.models.invite_config.InviteConfig(), 
                                                                code = '', 
                                                                status = 'PREVIEW', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                created_by_id = '', 
                                                                project_id = '', )
                                                            ], 
                                                        chat_sessions = [
                                                            keplar_api.models.chat_session.ChatSession(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                created_by_id = '', 
                                                                project_id = '', 
                                                                chat_messages = [
                                                                    keplar_api.models.chat_message.ChatMessage(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        content = '', 
                                                                        role = 'user', 
                                                                        chat_session_id = '', 
                                                                        chat_session = keplar_api.models.chat_session.ChatSession(
                                                                            id = '', 
                                                                            name = '', 
                                                                            description = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            created_by_id = '', 
                                                                            project_id = '', ), )
                                                                    ], )
                                                            ], 
                                                        project_files = [
                                                            keplar_api.models.project_file.ProjectFile(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                project_id = '', 
                                                                file_id = '', 
                                                                description = '', )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_group = [
                                                            
                                                            ], 
                                                        artifacts = , 
                                                        artifact_version_group = [
                                                            
                                                            ], )
                                                    ], 
                                                moderators = [
                                                    
                                                    ], 
                                                files = [
                                                    
                                                    ], 
                                                threads = , 
                                                attribute_kind_groups = [
                                                    
                                                    ], 
                                                workspace_members = [
                                                    keplar_api.models.workspace_member.WorkspaceMember(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        role = 'owner', 
                                                        user_id = '', 
                                                        workspace_id = '', )
                                                    ], 
                                                notebooks = [
                                                    
                                                    ], 
                                                default_for_users = [
                                                    
                                                    ], 
                                                default_for_orgs = [
                                                    
                                                    ], ), 
                                            workspace_members = , 
                                            projects = [
                                                
                                                ], 
                                            invites = [
                                                
                                                ], 
                                            chat_sessions = [
                                                
                                                ], 
                                            moderators = , 
                                            uploaded_files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_group = [
                                                
                                                ], 
                                            notebooks = , )
                                        ], 
                                    default_workspace = , ), 
                                default_workspace = , 
                                workspace_members = , 
                                projects = , 
                                invites = , 
                                chat_sessions = , 
                                moderators = , 
                                uploaded_files = [
                                    
                                    ], 
                                threads = , 
                                attribute_kind_group = , 
                                notebooks = , ), 
                            workspace = , 
                            moderator = , 
                            invites = , 
                            chat_sessions = , 
                            project_files = , 
                            threads = , 
                            attribute_kind_group = , 
                            artifacts = , 
                            artifact_version_group = [
                                
                                ], ), 
                        attribute_kind_group = , 
                        version_group = , 
                        latest_for_group = , 
                        created_by = , )
                    ],
                notebooks = [
                    keplar_api.models.notebook.Notebook(
                        id = '', 
                        workspace_id = '', 
                        created_by_id = '', 
                        name = '', 
                        description = '', 
                        config = keplar_api.models.notebook_config.NotebookConfig(
                            sources = [
                                ''
                                ], 
                            mode = 'report', 
                            settings = keplar_api.models.settings.settings(), ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        workspace = keplar_api.models.workspace.Workspace(
                            id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            projects = [
                                keplar_api.models.project.Project(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    description = '', 
                                    status = 'ACTIVE', 
                                    created_by_id = '', 
                                    workspace_id = '', 
                                    moderator_id = '', 
                                    config = keplar_api.models.project_config.ProjectConfig(
                                        project_kind = 'custom', 
                                        prompt_variables = {
                                            'key' : null
                                            }, 
                                        learning_plan = '', 
                                        brief = keplar_api.models.project_brief.ProjectBrief(
                                            title = '', 
                                            objective = '', 
                                            learning_goals = '', 
                                            key_questions = '', 
                                            conversation_flow = [
                                                ''
                                                ], 
                                            rules = [
                                                ''
                                                ], 
                                            assets = [
                                                ''
                                                ], ), 
                                        current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                            doc = keplar_api.models.brief_document.BriefDocument(
                                                type = 'doc', 
                                                content = [
                                                    keplar_api.models.content_node.ContentNode()
                                                    ], ), 
                                            version = 1.337, 
                                            created_at = '', 
                                            updated_at = '', ), 
                                        brief_document = '', 
                                        screener_questions = [
                                            keplar_api.models.screener_question.ScreenerQuestion()
                                            ], 
                                        audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                            sample_size = 1.337, 
                                            invite_title = '', 
                                            invite_description = '', 
                                            participants = [
                                                keplar_api.models.participant_create.ParticipantCreate(
                                                    id = '', 
                                                    name = '', 
                                                    email = '', 
                                                    phone_number = '01234', 
                                                    data = keplar_api.models.data.data(), )
                                                ], 
                                            panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                respondent_attributes = [
                                                    keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                        qualifications = [
                                                            keplar_api.models.panel_qualification.PanelQualification(
                                                                allowed_option_ids = [
                                                                    null
                                                                    ], 
                                                                question_id = 1.337, )
                                                            ], 
                                                        quota = 1.337, 
                                                        quota_name = '', )
                                                    ], 
                                                country_code = '', 
                                                language_code = '', 
                                                length_of_interview = 1.337, 
                                                incidence_rate = 1.337, 
                                                compensation = 1.337, ), 
                                            use_public_link = True, ), ), 
                                    conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                        first_message = '', 
                                        end_call_message = '', 
                                        max_duration_seconds = 1.337, 
                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                            provider = 'vapi', 
                                            voice_id = 'Elliot', ), 
                                        language = 'en', ), 
                                    analysis = keplar_api.models.project_analysis.ProjectAnalysis(
                                        report = keplar_api.models.project_analysis_report.ProjectAnalysis_report(
                                            markdown_report = '', 
                                            structured_report = null, 
                                            call_ids = [
                                                ''
                                                ], 
                                            references = {
                                                'key' : ''
                                                }, ), ), 
                                    created_by = keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        data = keplar_api.models.user_data.UserData(
                                            launch_trial = True, 
                                            admin_level = 'ADMIN', 
                                            is_dummy = True, ), 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_kind = 'email_verification', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        org = keplar_api.models.org.Org(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            domain = '', 
                                            default_workspace_id = '', 
                                            users = [
                                                keplar_api.models.user.User(
                                                    id = '', 
                                                    seq = 1.337, 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    provider = 'google', 
                                                    user_id = '', 
                                                    email = '', 
                                                    name = '', 
                                                    account_status = 'ACTIVE', 
                                                    location = '', 
                                                    profile_image_url = '', 
                                                    password_hash = '', 
                                                    email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    token = '', 
                                                    token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    org_id = '', 
                                                    default_workspace_id = '', 
                                                    default_workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        moderators = [
                                                            keplar_api.models.moderator.Moderator(
                                                                id = '', 
                                                                name = '', 
                                                                description = '', 
                                                                visibility = 'public', 
                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                    system_prompt = '', 
                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                        provider = 'openai', 
                                                                        model = 'gpt-4.1', ), 
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    tools = [
                                                                        keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                            type = 'function', 
                                                                            function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                name = '', 
                                                                                description = '', 
                                                                                parameters = {
                                                                                    'key' : null
                                                                                    }, ), )
                                                                        ], ), 
                                                                vendor = 'vapi', 
                                                                vendor_id = '', 
                                                                vendor_data = null, 
                                                                workspace_id = '', 
                                                                created_by_id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                parent_moderator_id = '', 
                                                                parent_moderator = keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = , ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    child_moderators = [
                                                                        
                                                                        ], ), 
                                                                child_moderators = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        files = [
                                                            keplar_api.models.file.File(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                filename = '', 
                                                                display_name = '', 
                                                                mime_type = 'image/jpeg', 
                                                                size = '', 
                                                                bucket_name = '', 
                                                                gcs_path = '', 
                                                                gcs_generation = '', 
                                                                uploaded_by_id = '', 
                                                                workspace_id = '', 
                                                                description = '', 
                                                                metadata = {
                                                                    'key' : null
                                                                    }, 
                                                                is_public = True, 
                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                public_url = '', 
                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                uploaded_by = , 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', 
                                                                        category = 'transcript', 
                                                                        project = keplar_api.models.project.Project(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            description = '', 
                                                                            status = 'ACTIVE', 
                                                                            created_by_id = '', 
                                                                            workspace_id = '', 
                                                                            moderator_id = '', 
                                                                            config = keplar_api.models.project_config.ProjectConfig(
                                                                                prompt_variables = {
                                                                                    'key' : null
                                                                                    }, 
                                                                                learning_plan = '', 
                                                                                brief_document = '', ), 
                                                                            conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = , ), 
                                                                            moderator = , 
                                                                            invites = [
                                                                                keplar_api.models.invite.Invite(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                    code = '', 
                                                                                    status = 'PREVIEW', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    calls = [
                                                                                        keplar_api.models.call.Call(
                                                                                            id = '', 
                                                                                            vendor = '', 
                                                                                            vendor_call_id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            duration_ms = 1.337, 
                                                                                            kind = 'VOICE_CALL', 
                                                                                            phone_number = '', 
                                                                                            invite_response_id = '', 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', 
                                                                                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                                                                                id = '', 
                                                                                                kind = 'VOICE_CALL', 
                                                                                                status = 'PENDING', 
                                                                                                evaluation = 'SYSTEM_PASS', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                invite_id = '', 
                                                                                                vendor_participant_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite = keplar_api.models.invite.Invite(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                    code = '', 
                                                                                                    status = 'PREVIEW', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', 
                                                                                                            participant = keplar_api.models.participant.Participant(
                                                                                                                id = '', 
                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                email = '', 
                                                                                                                phone_number = '', 
                                                                                                                name = '', 
                                                                                                                workspace_id = '', 
                                                                                                                invite_responses = [
                                                                                                                    keplar_api.models.invite_response.InviteResponse(
                                                                                                                        id = '', 
                                                                                                                        kind = 'VOICE_CALL', 
                                                                                                                        status = 'PENDING', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        invite_id = '', 
                                                                                                                        vendor_participant_id = '', 
                                                                                                                        participant_id = '', 
                                                                                                                        invite_response_attributes = [
                                                                                                                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                                invite_response_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        attributes = [
                                                                                                                                            keplar_api.models.attribute.Attribute(
                                                                                                                                                id = '', 
                                                                                                                                                attribute_kind_id = '', 
                                                                                                                                                value = '', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                participant_attributes = [
                                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                        participant_id = '', 
                                                                                                                                                        attribute_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                    ], )
                                                                                                                                            ], 
                                                                                                                                        attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                            id = '', 
                                                                                                                                            name = '', 
                                                                                                                                            description = '', 
                                                                                                                                            scope = 'org', 
                                                                                                                                            purpose = 'screener_response', 
                                                                                                                                            workspace_id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            created_by_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            attribute_kinds = [
                                                                                                                                                keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                    id = '', 
                                                                                                                                                    key = '', 
                                                                                                                                                    label = '', 
                                                                                                                                                    value_kind = 'single', 
                                                                                                                                                    description = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    attribute_kind_group_id = '', )
                                                                                                                                                ], 
                                                                                                                                            artifacts = [
                                                                                                                                                keplar_api.models.artifact.Artifact(
                                                                                                                                                    id = '', 
                                                                                                                                                    title = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                                    version_group_id = '', 
                                                                                                                                                    metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                        status = 'draft', 
                                                                                                                                                        status_message = '', 
                                                                                                                                                        progress = 1.337, 
                                                                                                                                                        description = '', ), 
                                                                                                                                                    created_by_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                        id = '', 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                                        latest_artifact_id = '', 
                                                                                                                                                        latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                            id = '', 
                                                                                                                                                            title = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                                                            version_group_id = '', 
                                                                                                                                                            metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                                status = 'draft', 
                                                                                                                                                                status_message = '', 
                                                                                                                                                                progress = 1.337, 
                                                                                                                                                                description = '', ), 
                                                                                                                                                            created_by_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                project_id = '', 
                                                                                                                                                                kind = , 
                                                                                                                                                                latest_artifact_id = '', 
                                                                                                                                                                notebook_artifact_version_groups = [
                                                                                                                                                                    keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        artifact_version_group_id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                            id = '', 
                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                            name = '', 
                                                                                                                                                                            description = '', 
                                                                                                                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                                sources = [
                                                                                                                                                                                    ''
                                                                                                                                                                                    ], 
                                                                                                                                                                                mode = 'report', 
                                                                                                                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                            threads = [
                                                                                                                                                                                keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                                    thread_files = [
                                                                                                                                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            thread_id = '', 
                                                                                                                                                                                            file_id = '', 
                                                                                                                                                                                            thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                name = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                                notebook_id = '', ), 
                                                                                                                                                                                            file = keplar_api.models.file.File(
                                                                                                                                                                                                id = '', 
                                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                filename = '', 
                                                                                                                                                                                                display_name = '', 
                                                                                                                                                                                                mime_type = 'image/jpeg', 
                                                                                                                                                                                                size = '', 
                                                                                                                                                                                                bucket_name = '', 
                                                                                                                                                                                                gcs_path = '', 
                                                                                                                                                                                                gcs_generation = '', 
                                                                                                                                                                                                uploaded_by_id = '', 
                                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                                description = '', 
                                                                                                                                                                                                is_public = True, 
                                                                                                                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                                public_url = '', 
                                                                                                                                                                                                public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                        ], )
                                                                                                                                                                                ], ), 
                                                                                                                                                                        artifact_version_group = , )
                                                                                                                                                                    ], ), ), 
                                                                                                                                                        notebook_artifact_version_groups = [
                                                                                                                                                            keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                id = '', 
                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                artifact_version_group_id = '', 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                            ], ), 
                                                                                                                                                    latest_for_group = , )
                                                                                                                                                ], ), ), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], ), )
                                                                                                                            ], )
                                                                                                                    ], 
                                                                                                                participant_attributes = , ), )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        
                                                                                                        ], ), 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', ), 
                                                                                                invite_response_attributes = [
                                                                                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                        invite_response_id = '', 
                                                                                                        attribute_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                    ], ), 
                                                                                            events = [
                                                                                                keplar_api.models.call_event.CallEvent(
                                                                                                    call_id = '', 
                                                                                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    kind = '', 
                                                                                                    data = keplar_api.models.call_event_data.CallEventData(), 
                                                                                                    call = keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        conversation_messages = [
                                                                                                            keplar_api.models.conversation_message.ConversationMessage(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                role = '', 
                                                                                                                source = '', 
                                                                                                                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                message = '', 
                                                                                                                duration = 1.337, 
                                                                                                                seconds_from_start = 1.337, 
                                                                                                                conversation_message_topic_index = 1.337, 
                                                                                                                conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                    call_id = '', 
                                                                                                                    index = 1.337, 
                                                                                                                    description = '', ), )
                                                                                                            ], 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], ), )
                                                                                                ], 
                                                                                            participant = , 
                                                                                            invite = , 
                                                                                            conversation_messages = [
                                                                                                keplar_api.models.conversation_message.ConversationMessage(
                                                                                                    call_id = '', 
                                                                                                    index = 1.337, 
                                                                                                    role = '', 
                                                                                                    source = '', 
                                                                                                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    message = '', 
                                                                                                    duration = 1.337, 
                                                                                                    seconds_from_start = 1.337, 
                                                                                                    conversation_message_topic_index = 1.337, )
                                                                                                ], 
                                                                                            conversation_message_topics = [
                                                                                                
                                                                                                ], )
                                                                                        ], 
                                                                                    participant_invites = [
                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                            code = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            participant_id = '', 
                                                                                            invite_id = '', )
                                                                                        ], 
                                                                                    invite_responses = , )
                                                                                ], 
                                                                            chat_sessions = [
                                                                                keplar_api.models.chat_session.ChatSession(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    created_by_id = '', 
                                                                                    project_id = '', 
                                                                                    chat_messages = [
                                                                                        keplar_api.models.chat_message.ChatMessage(
                                                                                            id = '', 
                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                            content = '', 
                                                                                            role = 'user', 
                                                                                            chat_session_id = '', 
                                                                                            chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', ), )
                                                                                        ], )
                                                                                ], 
                                                                            threads = [
                                                                                
                                                                                ], 
                                                                            attribute_kind_group = [
                                                                                keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                    id = '', 
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    scope = 'org', 
                                                                                    purpose = 'screener_response', 
                                                                                    workspace_id = '', 
                                                                                    project_id = '', 
                                                                                    created_by_id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                ], 
                                                                            artifacts = [
                                                                                
                                                                                ], 
                                                                            artifact_version_group = [
                                                                                
                                                                                ], ), 
                                                                        file = , )
                                                                    ], 
                                                                thread_files = [
                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        thread_id = '', 
                                                                        file_id = '', )
                                                                    ], )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', 
                                                                user = , )
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            keplar_api.models.org.Org(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                domain = '', 
                                                                default_workspace_id = '', )
                                                            ], ), 
                                                    workspace_members = [
                                                        keplar_api.models.workspace_member.WorkspaceMember(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            role = 'owner', 
                                                            user_id = '', 
                                                            workspace_id = '', )
                                                        ], 
                                                    invites = [
                                                        
                                                        ], 
                                                    chat_sessions = [
                                                        
                                                        ], 
                                                    moderators = [
                                                        
                                                        ], 
                                                    uploaded_files = [
                                                        
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = [
                                                        
                                                        ], 
                                                    artifact = [
                                                        
                                                        ], )
                                                ], 
                                            default_workspace = , ), 
                                        default_workspace = , 
                                        workspace_members = , 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], ), 
                                    moderator = , 
                                    invites = , 
                                    chat_sessions = , 
                                    project_files = [
                                        keplar_api.models.project_file.ProjectFile(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            project_id = '', 
                                            file_id = '', 
                                            description = '', )
                                        ], 
                                    threads = , 
                                    attribute_kind_group = , 
                                    artifacts = , 
                                    artifact_version_group = [
                                        
                                        ], )
                                ], 
                            participants = [
                                
                                ], 
                            moderators = , 
                            files = [
                                
                                ], 
                            threads = , 
                            attribute_kind_groups = [
                                
                                ], 
                            workspace_members = , 
                            default_for_users = [
                                
                                ], 
                            default_for_orgs = [
                                
                                ], ), 
                        created_by = , 
                        threads = , 
                        notebook_artifact_version_groups = , )
                    ]
            )
        else:
            return User(
                id = '',
                seq = 1.337,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                provider = 'google',
                user_id = '',
                email = '',
                name = '',
                account_status = 'ACTIVE',
                default_workspace_id = '',
        )
        """

    def testUser(self):
        """Test User"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
